"""
Definition for all enneoxOS senosrs
"""

from .const import Identifier, SMATagList
from .sensor import Sensor

DEFAULT_TIMEOUT = 8

""" The profiles are necessary because the devices generally
    return a significantly lower number of measured values without sunlight. """
ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
    (
        [9492, 9491, 9489, 9488],  # Tripower X
        [
            "Coolsys.Inverter.TmpVal.1",
            "Coolsys.Inverter.TmpVal.2",
            "Coolsys.Inverter.TmpVal.3",
            "DcMs.Amp.1",
            "DcMs.Amp.2",
            "DcMs.Amp.3",
            "DcMs.TotDcEnCntWh.1",
            "DcMs.TotDcEnCntWh.2",
            "DcMs.TotDcEnCntWh.3",
            "DcMs.Vol.1",
            "DcMs.Vol.2",
            "DcMs.Vol.3",
            "DcMs.Watt.1",
            "DcMs.Watt.2",
            "DcMs.Watt.3",
            "GridGuard.Cntry",
            "GridMs.A.phsA",
            "GridMs.A.phsB",
            "GridMs.A.phsC",
            "GridMs.GriTyp",
            "GridMs.Hz",
            "GridMs.PhV.phsA",
            "GridMs.PhV.phsA2B",
            "GridMs.PhV.phsB",
            "GridMs.PhV.phsB2C",
            "GridMs.PhV.phsC",
            "GridMs.PhV.phsC2A",
            "GridMs.TotA",
            "GridMs.TotPFEEI",
            "GridMs.TotPFExt",
            "GridMs.TotPFPrc",
            "GridMs.TotVA",
            "GridMs.TotVAr",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "GridMs.VA.phsA",
            "GridMs.VA.phsB",
            "GridMs.VA.phsC",
            "GridMs.VAr.phsA",
            "GridMs.VAr.phsB",
            "GridMs.VAr.phsC",
            "GridMs.W.phsA",
            "GridMs.W.phsB",
            "GridMs.W.phsC",
            "InOut.GI1",  # codespell:ignore
            "Inverter.VArModCfg.PFCtlVolCfg.Stt",
            "Isolation.FltA",
            "Isolation.LeakRis",
            "Metering.TotFeedTms",
            "Metering.TotOpTms",
            "Metering.TotWhOut",
            "Metering.TotWhOut.Pv",
            "Operation.BckStt",
            "Operation.DrtStt",
            "Operation.Evt.Dsc",
            "Operation.Evt.EvtNo",
            "Operation.Evt.Msg",
            "Operation.EvtCntIstl",
            "Operation.EvtCntUsr",
            "Operation.GriSwCnt",
            "Operation.GriSwStt",
            "Operation.Health",
            "Operation.HealthStt.Alm",
            "Operation.HealthStt.Ok",
            "Operation.HealthStt.Wrn",
            "Operation.OpStt",
            "Operation.PvGriConn",
            "Operation.RstrLokStt",
            "Operation.RunStt",
            "Operation.StandbyStt",
            "Operation.VArCtl.VArModAct",
            "Operation.VArCtl.VArModStt",
            "Operation.WMaxLimSrc",
            "Operation.WMinLimSrc",
            "PvGen.PvW",
            "PvGen.PvWh",
            "Spdwr.ComSocA.Stt",
            "SunSpecSig.SunSpecTx.1",
            "Upd.Stt",
            "WebConn.Stt",
            "Wl.AcqStt",
            "Wl.AntMod",
            "Wl.ConnStt",
            "Wl.SigPwr",
            "Wl.SoftAcsConnStt",
            "Setpoint.PlantControl.InOut.GO1",  # codespell:ignore
            "Inverter.WMax",
        ],
    ),
    (
        [9483, 9484],  # Charger
        [
            "ChaSess.WhIn",
            "Chrg.ModSw",
            "GridMs.A.phsA",
            "GridMs.A.phsB",
            "GridMs.A.phsC",
            "GridMs.Hz",
            "GridMs.PhV.phsA",
            "GridMs.PhV.phsB",
            "GridMs.PhV.phsC",
            "GridMs.TotPF",
            "GridMs.TotVA",
            "GridMs.TotVAr",
            "InOut.GI1",  # codespell:ignore
            "Metering.GridMs.TotWIn",
            "Metering.GridMs.TotWIn.ChaSta",
            "Metering.GridMs.TotWhIn",
            "Metering.GridMs.TotWhIn.ChaSta",
            "Operation.EVeh.ChaStt",
            "Operation.EVeh.Health",
            "Operation.Evt.Msg",
            "Operation.Health",
            "Operation.WMaxLimNom",
            "Operation.WMaxLimSrc",
            "Wl.AcqStt",
            "Wl.ConnStt",
            "Wl.SigPwr",
            "Wl.SoftAcsConnStt",
        ],
    ),
    (
        [19085, 19128, 19129, 19130],  # Sunny Boy Smart Energy 3.6, 4.0, 5.0, 6.0
        [
            "Operation.Bat.Health.1",
            "Coolsys.Inverter.TmpVal.1",
            "DcMs.Amp.1",
            "DcMs.Amp.2",
            "DcMs.Amp.3",
            "DcMs.TotDcEnCntWh.1",
            "DcMs.TotDcEnCntWh.2",
            "DcMs.TotDcEnCntWh.3",
            "DcMs.Vol.1",
            "DcMs.Vol.2",
            "DcMs.Vol.3",
            "DcMs.Watt.1",
            "DcMs.Watt.2",
            "DcMs.Watt.3",
            "GridGuard.Cntry",
            "GridMs.A.phsA",
            "GridMs.A.phsA",
            "GridMs.GriTyp",
            "GridMs.Hz",
            "GridMs.PhV.phsA2B",
            "GridMs.PhV.phsA",
            "GridMs.TotA",
            "GridMs.TotPFEEI",
            "GridMs.TotPFExt",
            "GridMs.TotPFPrc",
            "GridMs.TotVA",
            "GridMs.TotVAr",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "GridMs.VA.phsA",
            "GridMs.VAr.phsA",
            "GridMs.W.phsA",
            "InOut.GI1",  # codespell:ignore
            "Inverter.VArModCfg.PFCtlVolCfg.Stt",
            "Isolation.FltA",
            "Isolation.LeakRis",
            "Metering.GridMs.TotWhIn.ChaSta",
            "Metering.GridMs.TotWhIn",
            "Metering.GridMs.TotWIn.ChaSta",
            "Metering.GridMs.TotWIn",
            "Metering.TotFeedTms",
            "Metering.TotOpTms",
            "Metering.TotWhOut",
            "Metering.TotWhOut.Pv",
            "Operation.BckStt",
            "Operation.DrtStt",
            "Operation.EvtCntIstl",
            "Operation.EvtCntUsr",
            "Operation.Evt.Dsc",
            "Operation.Evt.Msg",
            "Operation.GriSwCnt",
            "Operation.GriSwStt",
            "Operation.Health",
            "Operation.HealthStt.Alm",
            "Operation.HealthStt.Ok",
            "Operation.HealthStt.Wrn",
            "Operation.OpStt",
            "Operation.PvGriConn",
            "Operation.RstrLokStt",
            "Operation.RunStt",
            "Operation.StandbyStt",
            "Operation.VArCtl.VArModAct",
            "Operation.WMaxLimSrc",
            "PvGen.PvWh",
            "PvGen.PvW",
            "Setpoint.PlantControl.InOut.GO1",  # codespell:ignore
            "Spdwr.ComSocA.Stt",
            "SunSpecSig.SunSpecTx.1",
            "Upd.Stt",
            "WebConn.Stt",
            "Wl.AcqStt",
            "Wl.AntMod",
            "Wl.ConnStt",
            "Wl.SigPwr",
            "Wl.SoftAcsConnStt",
            "Bat.Amp.1",
            "Bat.ChaStt",
            "Bat.ChaSttArr.1",
            "Bat.Diag.VolMax.1",
            "Bat.OpTms.1",
            "Bat.Vol.1",
            "BatChrg.BatChrg",
            "BatChrg.BatChrgArr.1",
            "BatChrg.CurBatCha",
            "BatChrg.CurBatChaArr.1",
            "BatDsch.BatDsch",
            "BatDsch.BatDschArr.1",
            "BatDsch.CurBatDsch",
            "BatDsch.CurBatDschArr.1",
            "DcMs.TotDcEnCntWh.1",
            "DcMs.TotDcEnCntWh.2",
            "DcMs.TotDcEnCntWh.3",
            "EpsMs.Amp",
            "EpsMs.Vol",
            "EpsMs.Watt",
            "GridGuard.Cntry",
            "GridMs.GriTyp",
            "GridMs.TotPFEEI",
            "GridMs.TotPFExt",
            "GridMs.TotPFPrc",
            "InOut.GI1",  # codespell:ignore
            "InOut.GO1",  # codespell:ignore
            "Inverter.VArModCfg.PFCtlVolCfg.Stt",
            "Isolation.LeakRis",
            "Metering.GridMs.TotWhIn.Bat",
            "Metering.GridMs.TotWhOut.Bat",
            "Metering.TotFeedTms",
            "Metering.TotOpTms",
            "Metering.TotWhIn",
            "Operation.Bat.Health",
            "Operation.BckStt",
            "Operation.DrtStt",
            "Operation.Evt.Dsc",
            "Operation.Evt.Msg",
            "Operation.EvtCntIstl",
            "Operation.EvtCntUsr",
            "Operation.GriSwCnt",
            "Operation.HealthStt.Alm",
            "Operation.HealthStt.Ok",
            "Operation.HealthStt.Wrn",
            "Operation.PvGriConn",
            "Operation.RstrLokStt",
            "Operation.RunStt",
            "Operation.StandbyStt",
            "Operation.VArCtl.VArModAct",
            "Operation.VArCtl.VArModStt",
            "Operation.WMaxLimSrc",
            "Operation.WMinLimSrc",
            "Portal.EnnexOS.ConnStt",
            "PvGen.PvW",
            "PvGen.PvWh",
            "Spdwr.ComSocA.Stt",
            "SunSpecSig.SunSpecTx.1",
            "Upd.Stt",
            "WebConn.Stt",
            "Wl.AcqStt",
            "Wl.AntMod",
            "Wl.ConnStt",
            "Wl.SigPwr",
            "Wl.SoftAcsConnStt",
            "Setpoint.PlantControl.CmpBMS.OpMod.1",
            "Metering.GridMs.TotWhIn.Bat",
            "Metering.GridMs.TotWhOut.Bat",
            "Inverter.WMax",
            "Bat.TmpVal.1",
        ],
    ),
    (
        [9397],  # Data Manager EDMM-10
        [
            "Operation.Health",
            "DevUpd.IsOn",
            "FTPPush.IsOn",
            "FTPPush.Login",
            "FTPPush.Port",
            "FTPPush.Pwd",
            "FTPPush.RemStoLcn",
            "FTPPush.Srv",
            "FTPPush.UpldCyc",
            "InOut.GI1",  # codespell:ignore
            "Nameplate.CmpMain.HwRev",
            "Nameplate.CmpMain.Rev",
            "Nameplate.CmpOS.SwRev",
            "Nameplate.Location",
            "Nameplate.MainModel",
            "Nameplate.Model",
            "Nameplate.ModelStr",
            "Nameplate.PkgRev",
            "Nameplate.SerNum",
            "Nameplate.Vendor",
            "Portal.EnnexOS.ConnStt",
            "Spdwr.ActlDnsSrvIp",
            "Spdwr.ActlGwIp",
            "Spdwr.ActlIp",
            "Spdwr.ActlSnetMsk",
            "Spdwr.AutoCfgIsOn",
            "Spdwr.IgmpQryTms",
            "Spdwr.IgmpQryTx",
            "SwCmp.CmpEnnexOS.Frwk.SwRev",
            "Sys.DevRstr",
            "Upd.AutoUpdIsOn",
            "WebConn.IsOn",
            "WebConn.Stt",
            "WebConn.SwRev",
        ],
    ),
    (
        [9307],  # Energy Meter
        [
            "Metering.GridMs.TotWIn",
            "Metering.GridMs.TotWhIn",
            "Metering.GridMs.TotWOut",
            "Metering.GridMs.TotWhOut",
            "Metering.GridMs.A.phsA",
            "Metering.GridMs.A.phsB",
            "Metering.GridMs.A.phsC",
            "Metering.GridMs.Hz",
            "Metering.GridMs.PhV.phsA",
            "Metering.GridMs.PhV.phsB",
            "Metering.GridMs.PhV.phsC",
            "Metering.GridMs.TotPF",
            "Metering.GridMs.W.phsA",
            "Metering.GridMs.W.phsB",
            "Metering.GridMs.W.phsC",
            "Operation.Health",
            "Metering.GridMs.VA.phsA",
            "Metering.GridMs.VA.phsB",
            "Metering.GridMs.VA.phsC",
            "Metering.GridMs.VAr.phsA",
            "Metering.GridMs.VAr.phsB",
            "Metering.GridMs.VAr.phsC",
        ],
    ),
    (
        [9054],  # SMC 7000TL via DataManager
        [
            "Coolsys.Inverter.TmpVal",
            "DcMs.Amp.1",
            "DcMs.Vol.1",
            "DcMs.Watt.1",
            "GridMs.A.phsA",
            "GridMs.A.phsB",
            "GridMs.A.phsC",
            "GridMs.Hz",
            "GridMs.PhV.phsA",
            "GridMs.PhV.phsB",
            "GridMs.PhV.phsC",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "Isolation.FltA",
            "Isolation.LeakRis",
            "Metering.TotFeedTms",
            "Metering.TotOpTms",
            "Metering.TotWhOut.Pv",
            "Operation.GriSwCnt",
            "Operation.Health",
            "Setpoint.PlantControl.Inverter.FstStop",
            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
            "GridGuard.Cntry.FrqCtl.hLim",
            "Metering.TotkWhOutSet",
            "GridGuard.Cntry.FrqCtl.Max",
            "Nameplate.CmpMain.SwRev",
            "Metering.TotFeedTmhSet",
            "GridGuard.Cntry.VolCtl.Rpro",
            "Nameplate.CmpCom.SwRev",
            "GridGuard.Cntry.Aid.PerAid.Ampl",
            "GridGuard.Cntry.VRefOfs",
            "Inverter.OffGri.HzdLim",
            "Inverter.StopTms",
            "DcCfg.StrTms",
            "GridGuard.Cntry.FrqCtl.hLimTmms",
            "Inverter.OffGri.HzdStr",
            "GridGuard.Cntry.Aid.PerAid.Hz",
            "GridGuard.Cntry.VolCtl.lLim",
            "Nameplate.Model",
            "GridGuard.CntrySet",
            "Inverter.WLim",
            "Coolsys.FanTst",
            "Operation.OpMod",
            "GridGuard.Cntry.VolCtl.llLimTmms",
            "GridGuard.Cntry.VolCtl.hhLim",
            "GridGuard.Cntry.VolCtl.llLim",
            "Nameplate.Location",
            "GridGuard.Cntry.VolCtl.hhLimTmms",
            "GridGuard.Cntry.FrqCtl.MaxTmms",
            "GridGuard.Cntry.VolCtl.hLimTmms",
            "GridGuard.Cntry.VolCtl.lLimTmms",
            "Inverter.OutPhs",
            "Inverter.WMax",
            "GridGuard.Cntry.FrqCtl.Min",
            "Nameplate.MainModel",
            "DcCfg.StrVol",
            "GridGuard.Cntry.FrqCtl.lLim",
            "GridGuard.Cntry.FrqCtl.lLimTmms",
            "Nameplate.Vendor",
            "DcCfg.ConstVolCtl.Vset",
            "GridGuard.Cntry.FrqCtl.ChgMax",
            "GridGuard.Cntry.VolCtl.hLim",
            "GridGuard.Cntry.Aid.AngFact",
            "GridGuard.Cntry.GridGuardRev",
            "GridGuard.Cntry.FrqCtl.MinTmms",
            "Operation.PwrBal.OpMod",
            "Operation.ValRsIstl",
            "Nameplate.SerNum",
            "GridGuard.Cntry.AMaxOfs",
            "GridGuard.Cntry.LeakRisMin",
        ],
    ),
    (
        [8001],  # SMC 9000TL-10 via DataManager
        [
            "Coolsys.Inverter.TmpVal",
            "DcMs.Amp.1",
            "DcMs.Vol.1",
            "DcMs.Watt.1",
            "DcMs.Amp.2",
            "DcMs.Vol.2",
            "DcMs.Watt.2",
            "GridGuard.Cntry",
            "GridMs.A.phsA",
            "GridMs.A.phsB",
            "GridMs.A.phsC",
            "GridMs.Hz",
            "GridMs.PhV.phsA",
            "GridMs.PhV.phsB",
            "GridMs.PhV.phsC",
            "GridMs.TotVA",
            "GridMs.TotVAr",
            "GridMs.TotVAr.Pv",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "GridMs.W.phsA",
            "GridMs.W.phsB",
            "GridMs.W.phsC",
            "Isolation.FltA",
            "Isolation.LeakRis",
            "Metering.TotFeedTms",
            "Metering.TotOpTms",
            "Metering.TotWhOut.Pv",
            "Operation.DrtStt",
            "Operation.Evt.EvtNo",
            "Operation.Evt.EvtNoShrt",
            "Operation.Evt.Prio",
            "Operation.EvtCntIstl",
            "Operation.EvtCntUsr",
            "Operation.GriSwCnt",
            "Operation.GriSwStt",
            "Operation.Health",
            "Operation.RmgTms",
            "Setpoint.PlantControl.Inverter.FstStop",
            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
            "Nameplate.CmpMdul.Rev",
            "Metering.TotkWhOutSet",
            "DcCfg.VolLim[]",
            "Metering.TotFeedTmhSet",
            "Nameplate.CmpMain.SwRev",
            "GridGuard.Cntry.VolCtl.Max",
            "Nameplate.CmpMain.HwRev",
            "GridGuard.Cntry.VolCtl.Rpro",
            "Nameplate.CmpRS485.HwRev",
            "Nameplate.CmpCom.Rev",
            "DcCfg.MPPShdw.IsOn",
            "Inverter.OffGri.HzdLim",
            "GridGuard.Cntry.FrqCtl.hLimTmms",
            "DcCfg.StrTms[]",
            "Bt.BtPwr",
            "Nameplate.Model",
            "GridGuard.CntrySet",
            "Inverter.WLim",
            "Coolsys.FanTst",
            "Operation.OpMod",
            "GridGuard.Cntry.PEOpnMon",
            "Nameplate.CmpRS485.SwRev",
            "GridGuard.Cntry.AMaxOfsTmms",
            "GridGuard.Cntry.VolCtl.hhLim",
            "Nameplate.CmpFltASw.Rev",
            "Inverter.WMaxTm",
            "GridGuard.Cntry.VolCtl.llLim",
            "Nameplate.Location",
            "GridGuard.Cntry.VolCtl.hLimTmms",
            "Nameplate.CmpSigProc.Rev",
            "GridGuard.Cntry.VolCtl.lLimTmms",
            "Inverter.OutPhs",
            "Nameplate.MainModel",
            "Nameplate.PkgRev",
            "GridGuard.Cntry.FrqCtl.lLimTmms",
            "Nameplate.CmpMdul.SwRev",
            "Nameplate.CmpFltASw.HwRev",
            "GridGuard.Cntry.Aid.AngFact",
            "DcCfg.MPPShdw.CycTms",
            "Nameplate.CmpRS485.Rev",
            "GridGuard.Cntry",
            "Operation.ValRsIstl",
            "Nameplate.SerNum",
            "GridGuard.Cntry.AMaxOfs",
            "GridGuard.Cntry.LeakRisMin",
            "Nameplate.CmpBt.SwRev",
            "GridGuard.Cntry.GriFltTms",
            "Metering.TotOpTmhSet",
            "GridGuard.Cntry.FrqCtl.hLim",
            "GridGuard.Cntry.FrqCtl.Max",
            "GridGuard.Cntry.GriStrTms",
            "Nameplate.CmpCom.SwRev",
            "GridGuard.Cntry.VolCtl.MaxTmms",
            "Inverter.StopTms",
            "Nameplate.CmpCom.HwRev",
            "Inverter.OffGri.HzdStr",
            "Nameplate.CmpMain.Rev",
            "GridGuard.Cntry.VolCtl.lLim",
            "Nameplate.CmpBt.Rev",
            "GridGuard.Cntry.GriFltReConTms",
            "GridGuard.Cntry.VolCtl.llLimTmms",
            "GridGuard.Cntry.VolCtl.hhLimTmms",
            "GridGuard.Cntry.FrqCtl.MaxTmms",
            "Nameplate.CmpDisp.Rev",
            "Nameplate.CmpDisp.SwRev",
            "Nameplate.CmpMdul.HwRev",
            "Nameplate.CmpSigProc.SwRev",
            "Inverter.WMax",
            "GridGuard.Cntry.FrqCtl.Min",
            "DcCfg.StrVol[]",
            "GridGuard.Cntry.FrqCtl.lLim",
            "Nameplate.ComRev",
            "Nameplate.CmpDisp.SerNum",
            "Nameplate.Vendor",
            "DcCfg.ConstVolCtl.Vset[]",
            "GridGuard.Cntry.VolCtl.hLim",
            "Nameplate.CmpFltASw.SwRev",
            "GridGuard.Cntry.GriFltMonTms",
            "GridGuard.Cntry.FrqCtl.MinTmms",
            "Operation.LodFnc",
        ],
    ),
    (
        [9056],  # "SMC 9000TL-10
        [
            "Coolsys.Cab.TmpValIstl",
            "Coolsys.Cab.TmpValMaxIstl",
            "Coolsys.Inverter.TmpVal",
            "DcMs.Amp.1",
            "DcMs.Vol.1",
            "DcMs.Watt.1",
            "DcMs.Amp.2",
            "DcMs.Vol.2",
            "DcMs.Watt.2",
            "GridMs.A.phsA",
            "GridMs.A.phsB",
            "GridMs.A.phsC",
            "GridMs.Hz",
            "GridMs.PhV.phsA",
            "GridMs.PhV.phsB",
            "GridMs.PhV.phsC",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "Isolation.FltA",
            "Isolation.LeakRis",
            "Metering.TotFeedTms",
            "Metering.TotOpTms",
            "Metering.TotWhOut.Pv",
            "Operation.GriSwCnt",
            "Operation.Health",
            "Setpoint.PlantControl.Inverter.FstStop",
            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
            "GridGuard.Cntry.FrqCtl.hLim",
            "GridGuard.Cntry.Aid.HzMon.HzLim",
            "Metering.TotkWhOutSet",
            "Nameplate.CmpMain.SwRev",
            "Metering.TotFeedTmhSet",
            "GridGuard.Cntry.VolCtl.Rpro",
            "Nameplate.CmpCom.SwRev",
            "GridGuard.Cntry.Aid.PerAid.Ampl",
            "GridGuard.Cntry.VRefOfs",
            "Inverter.OffGri.HzdLim",
            "Inverter.StopTms",
            "DcCfg.StrTms",
            "Inverter.OffGri.HzdStr",
            "GridGuard.Cntry.Aid.PerAid.Hz",
            "GridGuard.Cntry.VolCtl.lLim",
            "Nameplate.Model",
            "GridGuard.CntrySet",
            "Inverter.WLim",
            "Coolsys.FanTst",
            "Operation.OpMod",
            "GridGuard.Cntry.VolCtl.hhLim",
            "GridGuard.Cntry.VolCtl.llLim",
            "Nameplate.Location",
            "Inverter.OutPhs",
            "Inverter.WMax",
            "Nameplate.MainModel",
            "DcCfg.StrVol",
            "GridGuard.Cntry.FrqCtl.lLim",
            "Nameplate.Vendor",
            "DcCfg.ConstVolCtl.Vset",
            "GridGuard.Cntry.FrqCtl.ChgMax",
            "GridGuard.Cntry.VolCtl.hLim",
            "GridGuard.Cntry.Aid.AngFact",
            "GridGuard.Cntry.GridGuardRev",
            "Operation.PwrBal.OpMod",
            "Operation.ValRsIstl",
            "Nameplate.SerNum",
            "GridGuard.Cntry.AMaxOfs",
            "GridGuard.Cntry.LeakRisMin",
        ],
    ),
    (
        [19047],  # STP 110-60
        [
            "DcMs.Amp.1",
            "DcMs.Vol.1",
            "DcMs.Watt.1",
            "DcMs.Amp.2",
            "DcMs.Vol.2",
            "DcMs.Watt.2",
            "GridMs.A.phsA",
            "GridMs.A.phsB",
            "GridMs.A.phsC",
            "GridMs.Hz",
            "GridMs.PhV.phsA",
            "GridMs.PhV.phsA2B",
            "GridMs.PhV.phsB",
            "GridMs.PhV.phsB2C",
            "GridMs.PhV.phsC",
            "GridMs.PhV.phsC2A",
            "GridMs.TotA",
            "GridMs.TotPFEEI",
            "GridMs.TotVA",
            "GridMs.TotVAr",
            "GridMs.TotVAr.Pv",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "Metering.TotWhOut",
            "Metering.TotWhOut.Pv",
            "Operation.Evt.EvtNo",
            "Operation.Evt.Msg",
            "Operation.FailCode",
            "Operation.GriSwStt",
            "Operation.Health",
            "Operation.OpStt",
            "Operation.PvGriConn",
            "Nameplate.Model",
            "Inverter.WLim",
            "Nameplate.Location",
            "Inverter.VArMaxQ1Rtg",
            "Nameplate.MainModel",
            "Nameplate.PkgRev",
            "Bat.CapacRtgWh",
            "Nameplate.SerNum",
            "Nameplate.ModelStr",
            "Spdwr.ActlIp",
            "Nameplate.ARtg",
            "Inverter.VArMaxQ4Rtg",
            "Bat.CapacRtg",
            "Nameplate.VendorStr",
        ],
    ),
    (
        [358],  # SB 4000TL-20
        [
            "DcMs.Amp.1",
            "DcMs.Vol.1",
            "DcMs.Watt.1",
            "DcMs.Amp.2",
            "DcMs.Vol.2",
            "DcMs.Watt.2",
            "Coolsys.Inverter.TmpVal",
            "GridGuard.Cntry",
            "GridMs.A.phsA",
            "GridMs.A.phsB",
            "GridMs.A.phsC",
            "GridMs.Hz",
            "GridMs.PhV.phsA",
            "GridMs.PhV.phsB",
            "GridMs.PhV.phsC",
            "GridMs.TotVA",
            "GridMs.TotVAr",
            "GridMs.TotVAr.Pv",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "GridMs.W.phsA",
            "GridMs.W.phsB",
            "GridMs.W.phsC",
            "Isolation.FltA",
            "Isolation.LeakRis",
            "Metering.TotFeedTms",
            "Metering.TotOpTms",
            "Metering.TotWhOut.Pv",
            "Operation.DrtStt",
            "Operation.Evt.EvtNo",
            "Operation.Evt.EvtNoShrt",
            "Operation.Evt.Prio",
            "Operation.EvtCntIstl",
            "Operation.EvtCntUsr",
            "Operation.GriSwCnt",
            "Operation.GriSwStt",
            "Operation.Health",
            "Operation.RmgTms",
            "Setpoint.PlantControl.Inverter.FstStop",
            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
            "Nameplate.CmpMdul.Rev",
            "Metering.TotkWhOutSet",
            "DcCfg.VolLim[]",
            "Metering.TotFeedTmhSet",
            "Nameplate.CmpMain.SwRev",
            "GridGuard.Cntry.VolCtl.Max",
            "Nameplate.CmpMain.HwRev",
            "GridGuard.Cntry.VolCtl.Rpro",
            "Nameplate.CmpRS485.HwRev",
            "Nameplate.CmpCom.Rev",
            "DcCfg.MPPShdw.IsOn",
            "Inverter.OffGri.HzdLim",
            "GridGuard.Cntry.FrqCtl.hLimTmms",
            "DcCfg.StrTms[]",
            "Bt.BtPwr",
            "Nameplate.Model",
            "GridGuard.CntrySet",
            "Inverter.WLim",
            "Coolsys.FanTst",
            "Operation.OpMod",
            "GridGuard.Cntry.PEOpnMon",
            "Nameplate.CmpRS485.SwRev",
            "GridGuard.Cntry.AMaxOfsTmms",
            "GridGuard.Cntry.VolCtl.hhLim",
            "Nameplate.CmpFltASw.Rev",
            "Inverter.WMaxTm",
            "GridGuard.Cntry.VolCtl.llLim",
            "Nameplate.Location",
            "GridGuard.Cntry.VolCtl.hLimTmms",
            "Nameplate.CmpSigProc.Rev",
            "GridGuard.Cntry.VolCtl.lLimTmms",
            "Inverter.OutPhs",
            "Nameplate.MainModel",
            "Nameplate.PkgRev",
            "GridGuard.Cntry.FrqCtl.lLimTmms",
            "Nameplate.CmpMdul.SwRev",
            "Nameplate.CmpFltASw.HwRev",
            "GridGuard.Cntry.Aid.AngFact",
            "DcCfg.MPPShdw.CycTms",
            "Nameplate.CmpRS485.Rev",
            "GridGuard.Cntry",
            "Operation.ValRsIstl",
            "Nameplate.SerNum",
            "GridGuard.Cntry.AMaxOfs",
            "GridGuard.Cntry.LeakRisMin",
            "Nameplate.CmpBt.SwRev",
            "GridGuard.Cntry.GriFltTms",
            "Metering.TotOpTmhSet",
            "GridGuard.Cntry.FrqCtl.hLim",
            "GridGuard.Cntry.FrqCtl.Max",
            "GridGuard.Cntry.GriStrTms",
            "Nameplate.CmpCom.SwRev",
            "GridGuard.Cntry.VolCtl.MaxTmms",
            "Inverter.StopTms",
            "Nameplate.CmpCom.HwRev",
            "Inverter.OffGri.HzdStr",
            "Nameplate.CmpMain.Rev",
            "GridGuard.Cntry.VolCtl.lLim",
            "Nameplate.CmpBt.Rev",
            "GridGuard.Cntry.GriFltReConTms",
            "GridGuard.Cntry.VolCtl.llLimTmms",
            "GridGuard.Cntry.VolCtl.hhLimTmms",
            "GridGuard.Cntry.FrqCtl.MaxTmms",
            "Nameplate.CmpDisp.Rev",
            "Nameplate.CmpDisp.SwRev",
            "Nameplate.CmpMdul.HwRev",
            "Nameplate.CmpSigProc.SwRev",
            "Inverter.WMax",
            "GridGuard.Cntry.FrqCtl.Min",
            "DcCfg.StrVol[]",
            "GridGuard.Cntry.FrqCtl.lLim",
            "Nameplate.ComRev",
            "Nameplate.CmpDisp.SerNum",
            "Nameplate.Vendor",
            "DcCfg.ConstVolCtl.Vset[]",
            "GridGuard.Cntry.VolCtl.hLim",
            "Nameplate.CmpFltASw.SwRev",
            "GridGuard.Cntry.GriFltMonTms",
            "GridGuard.Cntry.FrqCtl.MinTmms",
            "Operation.LodFnc",
        ],
    ),
    (
        [19143],  # EC22-3AC-20
        [
            "Acs.AuthRegistStt",
            "ChaSess.WhIn",
            "Chrg.ModSw",
            "GridMs.A.phsA",
            "GridMs.A.phsB",
            "GridMs.A.phsC",
            "GridMs.PhV.phsA",
            "GridMs.PhV.phsB",
            "GridMs.PhV.phsC",
            "GridMs.TotVA",
            "GridMs.TotVAr",
            "GridMs.VA.phsA",
            "GridMs.VA.phsB",
            "GridMs.VA.phsC",
            "GridMs.VAr.phsA",
            "GridMs.VAr.phsB",
            "GridMs.VAr.phsC",
            "GridMs.W.phsA",
            "GridMs.W.phsB",
            "GridMs.W.phsC",
            "InOut.GI1",  # codespell:ignore
            "InOut.GO1",  # codespell:ignore
            "Metering.GridMs.TotWIn.ChaSta",
            "Metering.GridMs.TotWhIn.ChaSta",
            "Operation.EVeh.ChaStt",
            "Operation.EVeh.Health",
            "Operation.Evt.Dsc",
            "Operation.Evt.EvtNo",
            "Operation.Evt.Msg",
            "Operation.EvtCntIstl",
            "Operation.EvtCntUsr",
            "Operation.Health",
            "Operation.WMaxLimSrc",
            "Spdwr.ComSocA.Stt",
            "Upd.Stt",
            "WebConn.Stt",
            "Wl.AcqStt",
            "Wl.AntMod",
            "Wl.ConnStt",
            "Wl.SigPwr",
            "Wl.SoftAcsConnStt",
            "Setpoint.PlantControl.PCC.ChrgActCnt",
            "Nameplate.Model",
            "Nameplate.CmpMain.SusyId",
            "Wl.DoWPS",
            "Chrg.Plan.En",
            "WebConn.SwRev",
            "Nameplate.MainModel",
            "PCC.ARtg",
            "Wl.Sec.Psk",
            "Spdwr.AutoCfgIsOn",
            "Acs.PwdIstl",
            "SwCmp.CmpComBlt.SwRev",
            "Sys.AmbLghtBri",
            "Nameplate.SerNum",
            "Spdwr.ActlSnetMsk",
            "Upd.AutoUpdIsOn",
            "Nameplate.ChrgCtrl.SusyId",
            "Inverter.AcALim",
            "Wl.ActlIp",
            "Nameplate.CmpCom.HwVer",
            "Wl.ActlSnetMsk",
            "Chrg.ActChaMod",
            "Sys.UseAmbLght",
            "Acs.PwdUsr",
            "Spdwr.ActlIp",
            "Chrg.Plan.StopTm",
            "Nameplate.CmpOS.SwRev",
            "Inverter.WMaxIn",
            "WebConn.IsOn",
            "PCC.WMaxAsym",
            "Nameplate.ARtg",
            "DtTm.NtpSrv",
            "Inverter.WMax",
            "Nameplate.ChrgCtrl.SerNumTxt",
            "Chrg.Plan.DurTmm",
            "Chrg.ChrgLok",
            "Nameplate.CmpCom.SerNum",
            "Wl.ActlDnsSrvIp",
            "Nameplate.MacId",
            "Nameplate.ChrgCtrl.SwRevTxt",
            "Wl.Sec.Cry",
            "Spdwr.IgmpQryTms",
            "Nameplate.CmpCom.Rev",
            "DevUpd.IsOn",
            "Nameplate.Location",
            "Spdwr.ActlDnsSrvIp",
            "Chrg.AMinCha",
            "Inverter.OutPhs",
            "Nameplate.PkgRev",
            "Wl.ActlGwIp",
            "PCC.FlbInv.WMax",
            "IecCfg.GoCfg.GoAppId",
            "Inverter.WMaxInRtg",
            "Mb.TcpSrv.IsOn",
            "Sys.DevSigBri",
            "SwCmp.CmpEnnexOS.Frwk.SwRev",
            "Nameplate.ChrgCtrl.ChrgTypTxt",
            "Chrg.CblLok",
            "Mb.ScdInEna",
            "Nameplate.ModelStr",
            "Spdwr.IgmpQryTx",
            "Spdwr.ActlGwIp",
            "Chrg.UseEnergyMeter",
            "Sys.DevRstr",
            "GridGuard.Cntry.VRtg",
            "Operation.ComTmOut",
            "Wl.Sec.Ssid",
            "Chrg.ChrgApv",
            "IecCfg.GoCfg.GoMacId",
            "Nameplate.WlMacId",
            "Upd.AvalChkIstl",
            "Nameplate.Vendor",
            "Wl.IsOn",
            "Nameplate.VendorStr",
            "Chrg.StpWhenFl",
            "Wl.AutoCfgIsOn",
            "Wl.SoftAcsIsOn",
            "Chrg.StpWhenFlTm",
            "Wl.DoAcq",
            "Sys.DevSig",
            "Mb.TcpSrv.Port",
        ],
    ),
    (
        [-47114711],  # Fake Number for Plants
        [
            "GridGuard.Cntry.FrqCtl.ReconMax",
            "GridGuard.Cntry.FrqCtl.ReconMin",
            "GridGuard.Cntry.GriFltMonTms",
            "GridGuard.Cntry.GriFltReConTms",
            "GridGuard.Cntry.GriFltTms",
            "GridGuard.Cntry.GriStrTms",
            "GridGuard.Cntry.VolCtl.ReconMaxPu",
            "GridGuard.Cntry.VolCtl.ReconMinPu",
            "GridMs.TotVAr",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "Inverter.CtlComCfg.PFCtlCom.CtlComMssMod",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFExtIn",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFExtOut",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFIn",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFOut",
            "Inverter.CtlComCfg.PFCtlCom.TmsOut",
            "Inverter.CtlComCfg.PFCtlEvu.AnInEna",
            "Inverter.CtlComCfg.PFCtlEvu.MbEna",
            "Inverter.CtlComCfg.VArCtlCom.CtlComMssMod",
            "Inverter.CtlComCfg.VArCtlCom.FlbVArNom",
            "Inverter.CtlComCfg.VArCtlCom.TmsOut",
            "Inverter.CtlComCfg.VArCtlEvu.AnInEna",
            "Inverter.CtlComCfg.VArCtlEvu.DigInEna",
            "Inverter.CtlComCfg.VArCtlEvu.MbEna",
            "Inverter.CtlComCfg.VArCtlVolCom.CtlComMssMod",
            "Inverter.CtlComCfg.VArCtlVolCom.FlbVolRefPu",
            "Inverter.CtlComCfg.VArCtlVolCom.TmsOut",
            "Inverter.CtlComCfg.WCtlCom2.CtlComMssMod",
            "Inverter.CtlComCfg.WCtlCom2.FlbWMaxNom",
            "Inverter.CtlComCfg.WCtlCom2.FlbWMinNom",
            "Inverter.CtlComCfg.WCtlCom2.TmsOut",
            "Inverter.CtlComCfg.WCtlCom.CtlComMssMod",
            "Inverter.CtlComCfg.WCtlCom.FlbWMaxNom",
            "Inverter.CtlComCfg.WCtlCom.FlbWMinNom",
            "Inverter.CtlComCfg.WCtlCom.TmsOut",
            "Inverter.CtlComCfg.WCtlDctMrk.MbEna",
            "Inverter.CtlComCfg.WCtlDctMrk.SmaSpotEna",
            "Inverter.CtlComCfg.WCtlEvu.AnInEna",
            "Inverter.CtlComCfg.WCtlEvu.DigInEna",
            "Inverter.CtlComCfg.WCtlEvu.MbEna",
            "Inverter.CurWCtlDrkNom",
            "Inverter.CurWCtlNom",
            "Inverter.DGSModCfg.AvLtTms",
            "Inverter.DGSModCfg.AvStTms",
            "Inverter.DGSModCfg.DGSFlCfg.DbVMaxPu",
            "Inverter.DGSModCfg.DGSFlCfg.DbVMinPu",
            "Inverter.DGSModCfg.DGSFlCfg.FltEnd.ArMaxTms",
            "Inverter.DGSModCfg.DGSFlCfg.StepVolPu",
            "Inverter.DGSModCfg.DGSMod",
            "Inverter.DGSModCfg.HystVolPu",
            "Inverter.DGSModCfg.VRefThMod",
            "Inverter.PFMinQ1",
            "Inverter.PFMinQ1Rtg",
            "Inverter.PFMinQ2",
            "Inverter.PFMinQ2Rtg",
            "Inverter.PFMinQ3",
            "Inverter.PFMinQ3Rtg",
            "Inverter.PFMinQ4",
            "Inverter.PFMinQ4Rtg",
            "Inverter.PlntCtl.VRef",
            "Inverter.PlntCtl.VRefMod",
            "Inverter.VALimEna",
            "Inverter.VAMaxIn",
            "Inverter.VAMaxInRtg",
            "Inverter.VAMaxOut",
            "Inverter.VAMaxOutRtg",
            "Inverter.VArGraConn",
            "Inverter.VArGraConnEna",
            "Inverter.VArMaxQ1",
            "Inverter.VArMaxQ1Rtg",
            "Inverter.VArMaxQ2",
            "Inverter.VArMaxQ2Rtg",
            "Inverter.VArMaxQ3",
            "Inverter.VArMaxQ3Rtg",
            "Inverter.VArMaxQ4",
            "Inverter.VArMaxQ4Rtg",
            "Inverter.VArMaxZerWQ1",
            "Inverter.VArMaxZerWQ2",
            "Inverter.VArMaxZerWQ3",
            "Inverter.VArMaxZerWQ4",
            "Inverter.VArModCfg.HystTms",
            "Inverter.VArModCfg.InWNomLimAct",
            "Inverter.VArModCfg.InWNomLimDeAct",
            "Inverter.VArModCfg.OutWNomLimAct",
            "Inverter.VArModCfg.OutWNomLimDeAct",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraEna",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.PFCfg.Dyn.VArTmEna",
            "Inverter.VArModCfg.PFCfg.Dyn.VArTms",
            "Inverter.VArModCfg.PFCfg.Dyn.WFilTmEna",
            "Inverter.VArModCfg.PFCfg.Dyn.WFilTms",
            "Inverter.VArModCfg.PFCnstCfg.PFExtIn",
            "Inverter.VArModCfg.PFCnstCfg.PFExtOut",
            "Inverter.VArModCfg.PFCnstCfg.PFIn",
            "Inverter.VArModCfg.PFCnstCfg.PFOut",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.NumPt",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.4",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.4",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.4",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.ActTms",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraEna",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArTmEna",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArTms",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.WFilTmEna",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.WFilTms",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.NumPt",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.3",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.4",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.3",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.4",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.3",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.4",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.ActTms",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraEna",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArTmEna",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArTms",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.WFilTmEna",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.WFilTms",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.DsaUnVolPu",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.DsaVolPu",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.EnaUnVolPu",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.EnaVolPu",
            "Inverter.VArModCfg.PFMinEna",
            "Inverter.VArModCfg.VArCfg.Crv.CrvEna",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.4",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.4",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraEna",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraFlb",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraFlbEna",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.VArCfg.Dyn.VArTmEna",
            "Inverter.VArModCfg.VArCfg.Dyn.VArTms",
            "Inverter.VArModCfg.VArCnstCfgDmd.VAr",
            "Inverter.VArModCfg.VArCnstCfgDmd.VArNom",
            "Inverter.VArModCfg.VArCnstCfgIn.VAr",
            "Inverter.VArModCfg.VArCnstCfgIn.VArNom",
            "Inverter.VArModCfg.VArCnstCfg.VAr",
            "Inverter.VArModCfg.VArCnstCfg.VArNom",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.PreSet",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.4",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.5",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.6",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.7",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.8",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.4",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.5",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.6",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.7",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.8",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.ActTms",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraEna",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArTmEna",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArTms",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.AutnAdjMod",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.AutnAdjTms",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.ClsCtl.DsaHiLimVArPu",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.ClsCtl.DsaLoLimVArPu",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.ClsCtl.EnaHiLimVArPu",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.ClsCtl.EnaLoLimVArPu",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.NumPt",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.10",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.4",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.5",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.6",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.7",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.8",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.9",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.10",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.4",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.5",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.6",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.7",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.8",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.9",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.ActTms",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraEna",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArTmEna",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArTms",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.DsaUnVolPu",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.DsaVolPu",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.EnaUnVolPu",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.EnaVolPu",
            "Inverter.VArModCfg.VArModIn",
            "Inverter.VArModCfg.VArModInFlb",
            "Inverter.VArModCfg.VArModOut",
            "Inverter.VArModCfg.VArModOutFlb",
            "Inverter.VArModCfg.VArModZerW",
            "Inverter.VArModCfg.VArModZerWFlb",
            "Inverter.VArModCfg.VArNomRefMod",
            "Inverter.VArModCfg.VRefMod",
            "Inverter.WAval",
            "Inverter.WCtlHzModCfg.Ena",
            "Inverter.WCtlHzModCfg.HzFilTmEna",
            "Inverter.WCtlHzModCfg.HzFilTms",
            "Inverter.WCtlHzModCfg.RefModOv",
            "Inverter.WCtlHzModCfg.RefModUn",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HystEnaOv",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HystEnaUn",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.3",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.3",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvStop",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzStopWGra",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzStopWGraTms",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.3",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.3",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnStop",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.WCtlChgOvUnTmms",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.WCtlTmms",
            "Inverter.WCtlHzModCfg.WGraEna",
            "Inverter.WCtlHzModCfg.WGraNeg",
            "Inverter.WCtlHzModCfg.WGraPos",
            "Inverter.WCtlHzModCfg.WTmEna",
            "Inverter.WCtlHzModCfg.WTms",
            "Inverter.WGraConn",
            "Inverter.WGraConnEna",
            "Inverter.WGraMpp",
            "Inverter.WGraRecon",
            "Inverter.WGraReconEna",
            "Inverter.WMax",
            "Inverter.WMaxIn",
            "Inverter.WMaxInRtg",
            "Inverter.WMaxOut",
            "Inverter.WMaxOutRtg",
            "Inverter.WModCfg.WCnstCfg.WNomEna",
            "Inverter.WModCfg.WCnstCfg.WNomPrc",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraEna",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraNeg",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraPos",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WTmEna",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WTms",
            "Inverter.WModCfg.WCtlComCfg2.Ena",
            "Inverter.WModCfg.WCtlComCfg2.LoPrioEna",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraEna",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraFlb",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraFlbEna",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraNeg",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraPos",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WTmEna",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WTms",
            "Inverter.WModCfg.WCtlComCfg.Ena",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.DbHzOv",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.DbHzUn",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzOv.1",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzOv.2",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzOv.3",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzOvGra.1",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzOvGra.2",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzOvGra.3",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzUn.1",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzUn.2",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzUn.3",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzUnGra.1",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzUnGra.2",
            "Inverter.WModCfg.WCtlHzFsmCfg.Crv.HzUnGra.3",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.HzFilTmEna",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.HzFilTms",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WAvalFilTmEna",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WAvalGraEna",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WAvalGraNeg",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WAvalGraPos",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WAvalTms",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WDifFilTmEna",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WDifFilTms",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WDifGraEna",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WDifGraNeg",
            "Inverter.WModCfg.WCtlHzFsmCfg.Dyn.WDifGraPos",
            "Inverter.WModCfg.WCtlHzFsmCfg.Ena",
            "Inverter.WModCfg.WCtlHzFsmCfg.WBaseMod",
            "Inverter.WModCfg.WCtlHzFsmCfg.WDifRefMod",
            "Inverter.WModCfg.WCtlHzFsmCfg.WResNom",
            "Inverter.WModCfg.WCtlHzILFCfg.DsaWaitTms",
            "Inverter.WModCfg.WCtlHzILFCfg.Ena",
            "Inverter.WModCfg.WCtlHzILFCfg.HzFilTmEna",
            "Inverter.WModCfg.WCtlHzILFCfg.HzFilTms",
            "Inverter.WModCfg.WCtlHzILFCfg.HzOvDsa",
            "Inverter.WModCfg.WCtlHzILFCfg.HzOvEna",
            "Inverter.WModCfg.WCtlHzILFCfg.HzStopMax",
            "Inverter.WModCfg.WCtlHzILFCfg.HzStopMin",
            "Inverter.WModCfg.WCtlHzILFCfg.HzStopWGra",
            "Inverter.WModCfg.WCtlHzILFCfg.HzUnDsa",
            "Inverter.WModCfg.WCtlHzILFCfg.HzUnEna",
            "Inverter.WModCfg.WCtlHzILFCfg.MbEna",
            "Inverter.WModCfg.WCtlHzILFCfg.WGra",
            "Inverter.WModCfg.WCtlVolCfg.ActTms",
            "Inverter.WModCfg.WCtlVolCfg.Crv.NumPt",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.1",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.2",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.3",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.4",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.5",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.6",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.7",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.8",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.1",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.2",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.3",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.4",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.5",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.6",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.7",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.8",
            "Inverter.WModCfg.WCtlVolCfg.Ena",
            "Inverter.WModCfg.WCtlVolCfg.VRefMod",
            "Inverter.WModCfg.WCtlVolCfg.WGraEna",
            "Inverter.WModCfg.WCtlVolCfg.WGraNeg",
            "Inverter.WModCfg.WCtlVolCfg.WGraPos",
            "Inverter.WModCfg.WCtlVolCfg.WRefMod",
            "Inverter.WModCfg.WCtlVolCfg.WTmEna",
            "Inverter.WModCfg.WCtlVolCfg.WTms",
            "Metering.DyWhOut",
            "Metering.GridMs.TotWhIn.Bat",
            "Metering.GridMs.TotWhOut.Bat",
            "Metering.PCCMs.PlntA.phsA",
            "Metering.PCCMs.PlntA.phsB",
            "Metering.PCCMs.PlntA.phsC",
            "Metering.PCCMs.PlntCsmpW",
            "Metering.PCCMs.PlntCsmpWh",
            "Metering.PCCMs.PlntHz",
            "Metering.PCCMs.PlntPF",
            "Metering.PCCMs.PlntPhV.phsA",
            "Metering.PCCMs.PlntPhV.phsB",
            "Metering.PCCMs.PlntPhV.phsC",
            "Metering.PCCMs.PlntVAr",
            "Metering.PCCMs.PlntVAr.phsA",
            "Metering.PCCMs.PlntVAr.phsB",
            "Metering.PCCMs.PlntVAr.phsC",
            "Metering.PCCMs.PlntW",
            "Metering.PCCMs.PlntWh",
            "Metering.PCCMs.PlntW.phsA",
            "Metering.PCCMs.PlntW.phsB",
            "Metering.PCCMs.PlntW.phsC",
            "Metering.TotWhOut.Pv",
            "Operation.CurAvailPlnt",
            "Operation.CurAvailVArOvExt",
            "Operation.CurAvailVArOvExtNom",
            "Operation.CurAvailVArUnExt",
            "Operation.CurAvailVArUnExtNom",
            "Operation.Dmd.WCtl",
            "Operation.Health",
            "Operation.NbrQodStt",
            "Operation.NbrRunStt",
            "Operation.NbrStopStt",
            "Operation.NbrWaitStt",
            "Operation.OpStt",
            "Operation.PlntCtl.VArCtlMod",
            "Operation.PlntCtl.WCtlMod",
            "Operation.VArCtl.VArModAct",
            "Operation.VArCtl.VArModStt",
            "Operation.VArMaxLimNom",
            "Operation.VArMinLimNom",
            "Operation.WMaxInLimNom",
            "Operation.WMaxLimNom",
            "Operation.WMaxLimSrc",
            "Operation.WMinInLimNom",
            "Operation.WMinLimNom",
            "Operation.WMinLimSrc",
            "PCC.WMaxAsym",
            "PCC.WMaxAsymMod",
            "PCC.WMaxAsymRefMod",
            "Plnt.CapacRtgWh",
            "PlntCtl.Frs.BatChaSttMax",
            "PlntCtl.Frs.BatChaSttMin",
            "PlntCtl.Frs.BatWhFilTms",
            "PlntCtl.Frs.CrvActHystTms",
            "PlntCtl.Frs.CrvActTms",
            "PlntCtl.Frs.CrvRmpZerWTms",
            "PlntCtl.Frs.DbHzOv",
            "PlntCtl.Frs.DbHzUn",
            "PlntCtl.Frs.Ena",
            "PlntCtl.Frs.HystWhRsvNom",
            "PlntCtl.Frs.RsvRmpZerWTms",
            "PlntCtl.Frs.RsvTms",
            "PlntCtl.Frs.RvyWhRsv.Ena",
            "PlntCtl.Frs.RvyWhRsv.WaitTms",
            "PlntCtl.Frs.RvyWhRsv.WGra",
            "PlntCtl.Frs.RvyWhRsv.WGraEna",
            "PlntCtl.Frs.RvyWhRsv.WMaxNom",
            "PlntCtl.Frs.WMaxNom",
            "PlntCtl.MaxPhsWCtlEna",
            "PlntCtl.MsFil.HzFilTmEna",
            "PlntCtl.MsFil.HzFilTms",
            "PlntCtl.MsFil.VArFilTmEna",
            "PlntCtl.MsFil.VArFilTms",
            "PlntCtl.MsFil.VolFilTmEna",
            "PlntCtl.MsFil.VolFilTms",
            "PlntCtl.MsFil.WFilTmEna",
            "PlntCtl.MsFil.WFilTms",
            "PlntCtl.SingleDevSptEna",
            "PlntCtl.SmpTm",
            "PlntCtl.VArCtl.DeActWaitTms",
            "PlntCtl.VArCtl.WPuLimAct",
            "PlntCtl.VArCtl.WPuLimDeAct",
            "PlntCtl.WCtlEvuRefMod",
            "PlntCtl.WNomInvStop",
            "Plnt.DcWRtg",
            "Plnt.Frs.Aval",
            "Plnt.TotAvalCha",
            "Plnt.TotAvalDsch",
            "Plnt.WRtg",
            "PortalUsrSettings.PlntNam",
            "InOut.DigIn.CurWCtlNom",  # codespell:ignore
        ],
    ),
    (
        [9404],  # SB5.0-1AV-41 (Sunny Boy 5.0 AV-41)
        [
            "Operation.RSSOpMode",
            "Inverter.VArModCfg.PFCnstCfg.PFOut",
            "Metering.TotkWhOutSet",
            "Nameplate.CmpMain.SwRev",
            "GridGuard.Cntry.AMaxOfsNom",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.NumPtMax",
            "DtTm.TmZn",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.3",
            "PCC.FlbInv.WMaxNom",
            "GridGuard.Cntry.VolCtl.ReconMaxPu",
            "Inverter.CtlComCfg.VArCtlVolCom.FlbVolRefPu",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.1",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.2",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.3",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.4",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.5",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.6",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.7",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.8",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.ActTms",
            "GridGuard.Cntry.PEOpnMon",
            "Inverter.WModCfg.GriSwOpnZerW",
            "Operation.CtrlType",
            "Inverter.VArModCfg.VArCfg.Dyn.VArTms",
            "Inverter.PFMinQ4Rtg",
            "Inverter.CtlComCfg.VArCtlCom.CtlComMssMod",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.4",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.5",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.6",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.7",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.8",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.9",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.10",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.11",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.12",
            "Inverter.VArModCfg.PFCnstCfg.PFIn",
            "Inverter.VArMaxQ1Rtg",
            "Inverter.CtlComCfg.PFCtlCom.FlbPF",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.WCtlTmms",
            "Inverter.WGraConnEna",
            "Nameplate.MainModel",
            "Wl.Sec.Psk",
            "Plnt.DcWRtg",
            "Nameplate.CmpCom.SusyId",
            "Inverter.WModCfg.WCnstCfg.W",
            "Spdwr.AutoCfgIsOn",
            "Inverter.VArModCfg.ImpCpn.CapacRis",
            "Acs.PwdIstl",
            "RS485.ConnSpd",
            "GridGuard.Cntry.VolCtl.RproPu",
            "Inverter.VArModCfg.InWNomLimAct",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzStopWGraTms",
            "Nameplate.SerNum",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraEna",
            "Inverter.VArModCfg.ImpCpn.InducRis",
            "Inverter.CtlComCfg.VArCtlCom.TmsOut",
            "Spdwr.ActlSnetMsk",
            "Metering.MsSpdwr.SerNumEN",
            "Inverter.VArModCfg.VArCnstCfg.VAr",
            "Upd.AutoUpdIsOn",
            "Inverter.WModCfg.WCtlVolCfg.ActTms",
            "GridGuard.Cntry.FrqCtl.SwMax",
            "Inverter.CtlComCfg.WCtlCom.FlbWMin",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.NumPtMax",
            "Inverter.WCtlHzModCfg.HzFilTmEna",
            "GridGuard.Cntry.VolCtl.MaxPeakPu",
            "GridGuard.Cntry.FrqCtl.SwMaxTmms",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraEna",
            "Inverter.DGSModCfg.ZerCurOvVolPu",
            "Wl.ActlSnetMsk",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.NumPt",
            "Inverter.WModCfg.WCtlVolCfg.Crv.NumPtMax",
            "Nameplate.CmpMain.Rev",
            "Spdwr.ActlIp",
            "Inverter.WModCfg.WMod",
            "Acs.Yap.SvcAllwdDt",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.DsaUnVolPu",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.AutnAdjTms",
            "Inverter.CtlComCfg.PFCtlCom.TmsOut",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraEna",
            "Inverter.VArModCfg.InWNomLimDeAct",
            "Inverter.WMaxIn",
            "PCC.EnMtrTmOut",
            "Nsd.ExsDev.1",
            "Nsd.ExsDev.2",
            "Nsd.ExsDev.3",
            "Nsd.ExsDev.4",
            "Nsd.ExsDev.5",
            "Nsd.ExsDev.6",
            "Nsd.ExsDev.7",
            "Nsd.ExsDev.8",
            "Nsd.ExsDev.9",
            "Nsd.ExsDev.10",
            "Nsd.ExsDev.11",
            "Nsd.ExsDev.12",
            "Nameplate.ARtg",
            "GridGuard.Cntry.VolCtl.ReconMinPu",
            "Metering.EnMtrARtg",
            "DtTm.NtpSrv",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WTms",
            "GridGuard.Cntry.FrqCtl.Min",
            "DcCfg.StrVol.1",
            "DcCfg.StrVol.2",
            "Inverter.PFMinQ3Rtg",
            "Eth.Proxy.IsOn",
            "Nameplate.ComRev",
            "Operation.SIS.IsOn",
            "Inverter.VArModCfg.VArModInFlb",
            "Nameplate.CmpCom.SerNum",
            "Wl.ActlDnsSrvIp",
            "Inverter.VArModCfg.VArCnstCfgIn.VAr",
            "GridGuard.Cntry.VolCtl.lLimPu",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnStop",
            "GridGuard.Cntry.FrqCtl.ReconMax",
            "Spdwr.Cry",
            "Operation.BckOpMod",
            "Wl.DnsSrvIp",
            "Nameplate.MacId",
            "DcCfg.PanLevMdul.SerNum.1",
            "DcCfg.PanLevMdul.SerNum.2",
            "DcCfg.PanLevMdul.SerNum.3",
            "DcCfg.PanLevMdul.SerNum.4",
            "DcCfg.PanLevMdul.SerNum.5",
            "DcCfg.PanLevMdul.SerNum.6",
            "DcCfg.PanLevMdul.SerNum.7",
            "DcCfg.PanLevMdul.SerNum.8",
            "DcCfg.PanLevMdul.SerNum.9",
            "DcCfg.PanLevMdul.SerNum.10",
            "DcCfg.PanLevMdul.SerNum.11",
            "DcCfg.PanLevMdul.SerNum.12",
            "DcCfg.PanLevMdul.SerNum.13",
            "DcCfg.PanLevMdul.SerNum.14",
            "DcCfg.PanLevMdul.SerNum.15",
            "DcCfg.PanLevMdul.SerNum.16",
            "DcCfg.PanLevMdul.SerNum.17",
            "DcCfg.PanLevMdul.SerNum.18",
            "DcCfg.PanLevMdul.SerNum.19",
            "DcCfg.PanLevMdul.SerNum.20",
            "DcCfg.PanLevMdul.SerNum.21",
            "DcCfg.PanLevMdul.SerNum.22",
            "DcCfg.PanLevMdul.SerNum.23",
            "DcCfg.PanLevMdul.SerNum.24",
            "DcCfg.PanLevMdul.SerNum.25",
            "DcCfg.PanLevMdul.SerNum.26",
            "DcCfg.PanLevMdul.SerNum.27",
            "DcCfg.PanLevMdul.SerNum.28",
            "DcCfg.PanLevMdul.SerNum.29",
            "DcCfg.PanLevMdul.SerNum.30",
            "DcCfg.PanLevMdul.SerNum.31",
            "DcCfg.PanLevMdul.SerNum.32",
            "DcCfg.PanLevMdul.SerNum.33",
            "DcCfg.PanLevMdul.SerNum.34",
            "DcCfg.PanLevMdul.SerNum.35",
            "DcCfg.PanLevMdul.SerNum.36",
            "DcCfg.PanLevMdul.SerNum.37",
            "DcCfg.PanLevMdul.SerNum.38",
            "DcCfg.PanLevMdul.SerNum.39",
            "DcCfg.PanLevMdul.SerNum.40",
            "DcCfg.PanLevMdul.SerNum.41",
            "DcCfg.PanLevMdul.SerNum.42",
            "DcCfg.PanLevMdul.SerNum.43",
            "DcCfg.PanLevMdul.SerNum.44",
            "DcCfg.PanLevMdul.SerNum.45",
            "DcCfg.PanLevMdul.SerNum.46",
            "DcCfg.PanLevMdul.SerNum.47",
            "DcCfg.PanLevMdul.SerNum.48",
            "DcCfg.PanLevMdul.SerNum.49",
            "DcCfg.PanLevMdul.SerNum.50",
            "DcCfg.PanLevMdul.SerNum.51",
            "DcCfg.PanLevMdul.SerNum.52",
            "DcCfg.PanLevMdul.SerNum.53",
            "DcCfg.PanLevMdul.SerNum.54",
            "DcCfg.PanLevMdul.SerNum.55",
            "DcCfg.PanLevMdul.SerNum.56",
            "DcCfg.PanLevMdul.SerNum.57",
            "DcCfg.PanLevMdul.SerNum.58",
            "DcCfg.PanLevMdul.SerNum.59",
            "DcCfg.PanLevMdul.SerNum.60",
            "Plnt.VARtg",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.EnaVolPu",
            "Inverter.WCtlHzModCfg.RefModOv",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraNeg",
            "GridGuard.Cntry.VolCtl.ConnMaxPu",
            "Inverter.PFMinQ4",
            "Mb.UntId",
            "Inverter.VArGraConn",
            "Spdwr.IgmpQryTms",
            "Inverter.WGraReconEna",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArTmsPrc",
            "Inverter.VArLimVolCfg.Ena",
            "Sys.ComDiag",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraNeg",
            "Inverter.PFMinQ3",
            "GridGuard.Cntry.VolCtl.hhLimPu",
            "CntrySettings.Lang",
            "Operation.OpMod",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.DsaVolPu",
            "RS485.Term",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.ActTms",
            "Nameplate.Location",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraEna",
            "Inverter.VArMaxQ3Rtg",
            "Inverter.PFMinQ2",
            "GridGuard.Cntry.VolCtl.RproTmms",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraEna",
            "GridGuard.Cntry.VolCtl.hLimTmms",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzStopWGra",
            "Inverter.VArModCfg.PFCfg.Dyn.WFilTmEna",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.3",
            "Inverter.VArModCfg.VArNomRefMod",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.3",
            "Acs.Yap.SvcIsAllwd",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraNeg",
            "DcCfg.PanLevMdul.Lbl.1",
            "DcCfg.PanLevMdul.Lbl.2",
            "DcCfg.PanLevMdul.Lbl.3",
            "DcCfg.PanLevMdul.Lbl.4",
            "DcCfg.PanLevMdul.Lbl.5",
            "DcCfg.PanLevMdul.Lbl.6",
            "DcCfg.PanLevMdul.Lbl.7",
            "DcCfg.PanLevMdul.Lbl.8",
            "DcCfg.PanLevMdul.Lbl.9",
            "DcCfg.PanLevMdul.Lbl.10",
            "DcCfg.PanLevMdul.Lbl.11",
            "DcCfg.PanLevMdul.Lbl.12",
            "DcCfg.PanLevMdul.Lbl.13",
            "DcCfg.PanLevMdul.Lbl.14",
            "DcCfg.PanLevMdul.Lbl.15",
            "DcCfg.PanLevMdul.Lbl.16",
            "DcCfg.PanLevMdul.Lbl.17",
            "DcCfg.PanLevMdul.Lbl.18",
            "DcCfg.PanLevMdul.Lbl.19",
            "DcCfg.PanLevMdul.Lbl.20",
            "DcCfg.PanLevMdul.Lbl.21",
            "DcCfg.PanLevMdul.Lbl.22",
            "DcCfg.PanLevMdul.Lbl.23",
            "DcCfg.PanLevMdul.Lbl.24",
            "DcCfg.PanLevMdul.Lbl.25",
            "DcCfg.PanLevMdul.Lbl.26",
            "DcCfg.PanLevMdul.Lbl.27",
            "DcCfg.PanLevMdul.Lbl.28",
            "DcCfg.PanLevMdul.Lbl.29",
            "DcCfg.PanLevMdul.Lbl.30",
            "DcCfg.PanLevMdul.Lbl.31",
            "DcCfg.PanLevMdul.Lbl.32",
            "DcCfg.PanLevMdul.Lbl.33",
            "DcCfg.PanLevMdul.Lbl.34",
            "DcCfg.PanLevMdul.Lbl.35",
            "DcCfg.PanLevMdul.Lbl.36",
            "DcCfg.PanLevMdul.Lbl.37",
            "DcCfg.PanLevMdul.Lbl.38",
            "DcCfg.PanLevMdul.Lbl.39",
            "DcCfg.PanLevMdul.Lbl.40",
            "DcCfg.PanLevMdul.Lbl.41",
            "DcCfg.PanLevMdul.Lbl.42",
            "DcCfg.PanLevMdul.Lbl.43",
            "DcCfg.PanLevMdul.Lbl.44",
            "DcCfg.PanLevMdul.Lbl.45",
            "DcCfg.PanLevMdul.Lbl.46",
            "DcCfg.PanLevMdul.Lbl.47",
            "DcCfg.PanLevMdul.Lbl.48",
            "DcCfg.PanLevMdul.Lbl.49",
            "DcCfg.PanLevMdul.Lbl.50",
            "DcCfg.PanLevMdul.Lbl.51",
            "DcCfg.PanLevMdul.Lbl.52",
            "DcCfg.PanLevMdul.Lbl.53",
            "DcCfg.PanLevMdul.Lbl.54",
            "DcCfg.PanLevMdul.Lbl.55",
            "DcCfg.PanLevMdul.Lbl.56",
            "DcCfg.PanLevMdul.Lbl.57",
            "DcCfg.PanLevMdul.Lbl.58",
            "DcCfg.PanLevMdul.Lbl.59",
            "DcCfg.PanLevMdul.Lbl.60",
            "Inverter.OutPhs",
            "Inverter.WGraRecon",
            "SwCmp.CmpMainBlt.SwRev",
            "Nameplate.PkgRev",
            "GridGuard.Cntry.HzRtg",
            "GridGuard.Cntry.FrqCtl.lLimTmms",
            "Inverter.CtlComCfg.WCtlCom.TmsOut",
            "Inverter.PFMinQ1",
            "GridGuard.Cntry.FrqCtl.ChgMax",
            "Inverter.CtlComCfg.VArCtlVolCom.TmsOut",
            "IecCfg.GoCfg.GoAppId",
            "Inverter.VArModCfg.PFCfg.Dyn.WFilTms",
            "Nameplate.PkgUpdAval",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.DsaVolPu",
            "GridGuard.Cntry.FrqCtl.ReconMaxFrqMax",
            "GridGuard.Cntry.FrqCtl.ConnMax",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.EnaUnVolPu",
            "Inverter.CtlComCfg.WCtlCom2.FlbWMin",
            "Wl.SnetMsk",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.4",
            "Metering.TotOpTmhSet",
            "GridGuard.Cntry.FrqCtl.hLim",
            "DcCfg.PanLevStrg.Lbl.1",
            "DcCfg.PanLevStrg.Lbl.2",
            "DcCfg.PanLevStrg.Lbl.3",
            "DcCfg.PanLevStrg.Lbl.4",
            "DcCfg.PanLevStrg.Lbl.5",
            "DcCfg.PanLevStrg.Lbl.6",
            "DcCfg.PanLevStrg.Lbl.7",
            "DcCfg.PanLevStrg.Lbl.8",
            "DcCfg.PanLevStrg.Lbl.9",
            "DcCfg.PanLevStrg.Lbl.10",
            "PCC.WMaxMod",
            "DtTm.SetDlSvTm",
            "GridGuard.CntryBas",
            "GridGuard.Cntry.GriStrTms",
            "Inverter.WModCfg.WCtlVolCfg.WTmEna",
            "Inverter.VArModCfg.VArModZerW",
            "Mb.ScdInEna",
            "GridGuard.Cntry.VolCtl.llLimPu",
            "Nameplate.ModelStr",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraPos",
            "Inverter.DGSModCfg.VArDynEna",
            "DcCfg.PanLevCtl.SerNum",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.ActTms",
            "Inverter.StopTms",
            "Nameplate.CmpCom.HwRev",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.EnaVolPu",
            "Spdwr.ActlGwIp",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.NumPt",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.NumPtMax",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArTms",
            "Inverter.VArModCfg.OutWNomLimDeAct",
            "GridGuard.Cntry.GriFltReConTms",
            "GridGuard.Cntry.VolCtl.MaxPeakTmms",
            "Inverter.WModCfg.WCtlVolCfg.WGraEna",
            "Inverter.VAMaxIn",
            "Spdwr.DnsSrvIp",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.1",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.2",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.3",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.4",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.5",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.6",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.7",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.8",
            "GridGuard.Cntry.VolCtl.hhLimTmms",
            "Inverter.VArMaxQ2Rtg",
            "Wl.Sec.Ssid",
            "GridGuard.Cntry.FrqCtl.SwMin",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.3",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.4",
            "GridGuard.Cntry.FrqCtl.ChgMaxTmms",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFIn",
            "Inverter.VArModCfg.OutWNomLimAct",
            "Inverter.VArModCfg.VArModOutFlb",
            "Card.DatLogUsr",
            "Nameplate.WlMacId",
            "DtTm.TmSynIsOn",
            "Inverter.WModCfg.WCtlVolCfg.WRefMod",
            "Nameplate.Vendor",
            "Nameplate.VendorStr",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArTmEna",
            "DcCfg.PanLevCom.SerNum.1",
            "DcCfg.PanLevCom.SerNum.2",
            "DcCfg.PanLevCom.SerNum.3",
            "DcCfg.PanLevCom.SerNum.4",
            "Wl.AutoCfgIsOn",
            "Metering.EnMtrTyp",
            "Wl.SoftAcsIsOn",
            "Inverter.VArModCfg.VArCnstCfgDmd.VAr",
            "Inverter.WCtlHzModCfg.HzFilTms",
            "GridGuard.Cntry.GriFltMonTms",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraPos",
            "Inverter.WModCfg.WCtlVolCfg.WTms",
            "Inverter.VArModCfg.PFCnstCfg.PFExtIn",
            "Inverter.DGSModCfg.ZerCurUnVolPu",
            "Operation.GrnLedWInd",
            "DcCfg.PanLevCom.Model.1",
            "DcCfg.PanLevCom.Model.2",
            "DcCfg.PanLevCom.Model.3",
            "DcCfg.PanLevCom.Model.4",
            "Inverter.CtlComCfg.WCtlCom.CtlComMssMod",
            "Inverter.VArMaxZerWQ4",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvStop",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.3",
            "Inverter.PlntCtl.VRef",
            "Inverter.WGraMpp",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.ActTms",
            "Metering.MsSpdwr.UsSerNumEN.1",
            "Metering.MsSpdwr.UsSerNumEN.2",
            "Metering.MsSpdwr.UsSerNumEN.3",
            "Metering.MsSpdwr.UsSerNumEN.4",
            "Metering.MsSpdwr.UsSerNumEN.5",
            "Metering.MsSpdwr.UsSerNumEN.6",
            "Metering.MsSpdwr.UsSerNumEN.7",
            "Metering.MsSpdwr.UsSerNumEN.8",
            "Metering.MsSpdwr.UsSerNumEN.9",
            "Metering.MsSpdwr.UsSerNumEN.10",
            "DcCfg.PanLevMdul.HwRev.1",
            "DcCfg.PanLevMdul.HwRev.2",
            "DcCfg.PanLevMdul.HwRev.3",
            "DcCfg.PanLevMdul.HwRev.4",
            "DcCfg.PanLevMdul.HwRev.5",
            "DcCfg.PanLevMdul.HwRev.6",
            "DcCfg.PanLevMdul.HwRev.7",
            "DcCfg.PanLevMdul.HwRev.8",
            "DcCfg.PanLevMdul.HwRev.9",
            "DcCfg.PanLevMdul.HwRev.10",
            "DcCfg.PanLevMdul.HwRev.11",
            "DcCfg.PanLevMdul.HwRev.12",
            "DcCfg.PanLevMdul.HwRev.13",
            "DcCfg.PanLevMdul.HwRev.14",
            "DcCfg.PanLevMdul.HwRev.15",
            "DcCfg.PanLevMdul.HwRev.16",
            "DcCfg.PanLevMdul.HwRev.17",
            "DcCfg.PanLevMdul.HwRev.18",
            "DcCfg.PanLevMdul.HwRev.19",
            "DcCfg.PanLevMdul.HwRev.20",
            "DcCfg.PanLevMdul.HwRev.21",
            "DcCfg.PanLevMdul.HwRev.22",
            "DcCfg.PanLevMdul.HwRev.23",
            "DcCfg.PanLevMdul.HwRev.24",
            "DcCfg.PanLevMdul.HwRev.25",
            "DcCfg.PanLevMdul.HwRev.26",
            "DcCfg.PanLevMdul.HwRev.27",
            "DcCfg.PanLevMdul.HwRev.28",
            "DcCfg.PanLevMdul.HwRev.29",
            "DcCfg.PanLevMdul.HwRev.30",
            "DcCfg.PanLevMdul.HwRev.31",
            "DcCfg.PanLevMdul.HwRev.32",
            "DcCfg.PanLevMdul.HwRev.33",
            "DcCfg.PanLevMdul.HwRev.34",
            "DcCfg.PanLevMdul.HwRev.35",
            "DcCfg.PanLevMdul.HwRev.36",
            "DcCfg.PanLevMdul.HwRev.37",
            "DcCfg.PanLevMdul.HwRev.38",
            "DcCfg.PanLevMdul.HwRev.39",
            "DcCfg.PanLevMdul.HwRev.40",
            "DcCfg.PanLevMdul.HwRev.41",
            "DcCfg.PanLevMdul.HwRev.42",
            "DcCfg.PanLevMdul.HwRev.43",
            "DcCfg.PanLevMdul.HwRev.44",
            "DcCfg.PanLevMdul.HwRev.45",
            "DcCfg.PanLevMdul.HwRev.46",
            "DcCfg.PanLevMdul.HwRev.47",
            "DcCfg.PanLevMdul.HwRev.48",
            "DcCfg.PanLevMdul.HwRev.49",
            "DcCfg.PanLevMdul.HwRev.50",
            "DcCfg.PanLevMdul.HwRev.51",
            "DcCfg.PanLevMdul.HwRev.52",
            "DcCfg.PanLevMdul.HwRev.53",
            "DcCfg.PanLevMdul.HwRev.54",
            "DcCfg.PanLevMdul.HwRev.55",
            "DcCfg.PanLevMdul.HwRev.56",
            "DcCfg.PanLevMdul.HwRev.57",
            "DcCfg.PanLevMdul.HwRev.58",
            "DcCfg.PanLevMdul.HwRev.59",
            "DcCfg.PanLevMdul.HwRev.60",
            "Inverter.VArModCfg.VRefMod",
            "DcCfg.PanLevCtl.PlntId",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.4",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.5",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.6",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.7",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.8",
            "Spdwr.SnetMsk",
            "Metering.MsSpdwr.MsCyc",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.WFilTms",
            "DcCfg.MPPShdw.IsOn",
            "Inverter.WModCfg.WCtlVolCfg.VRefMod",
            "Metering.GridMs.TotkWhInOfs",
            "GridGuard.Cntry.FrqCtl.hLimTmms",
            "Inverter.VArModCfg.VArCfg.Crv.CrvEna",
            "Eth.Proxy.Login",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.WFilTmEna",
            "Nameplate.Model",
            "Inverter.WLim",
            "GridGuard.Cntry.VolCtl.MinTmms",
            "Metering.Mb.SwRev",
            "GridGuard.Cntry.AMaxOfsTmms",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.VArCnstCfgDmd.VArNom",
            "Inverter.CtlComCfg.VArCtlCom.FlbVArNom",
            "Nameplate.CmpMain.SusyId",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraNeg",
            "Inverter.CtlComCfg.WCtlCom2.FlbWMax",
            "GridGuard.Cntry.Aid.HzMon.Stt",
            "Inverter.VAMaxOut",
            "GridGuard.Cntry.VolCtl.lLimTmms",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.EnaUnVolPu",
            "WebConn.SwRev",
            "Inverter.VArModCfg.PFCnstCfg.PFExtOut",
            "DcCfg.PanLevMdul.SwRev.1",
            "DcCfg.PanLevMdul.SwRev.2",
            "DcCfg.PanLevMdul.SwRev.3",
            "DcCfg.PanLevMdul.SwRev.4",
            "DcCfg.PanLevMdul.SwRev.5",
            "DcCfg.PanLevMdul.SwRev.6",
            "DcCfg.PanLevMdul.SwRev.7",
            "DcCfg.PanLevMdul.SwRev.8",
            "DcCfg.PanLevMdul.SwRev.9",
            "DcCfg.PanLevMdul.SwRev.10",
            "DcCfg.PanLevMdul.SwRev.11",
            "DcCfg.PanLevMdul.SwRev.12",
            "DcCfg.PanLevMdul.SwRev.13",
            "DcCfg.PanLevMdul.SwRev.14",
            "DcCfg.PanLevMdul.SwRev.15",
            "DcCfg.PanLevMdul.SwRev.16",
            "DcCfg.PanLevMdul.SwRev.17",
            "DcCfg.PanLevMdul.SwRev.18",
            "DcCfg.PanLevMdul.SwRev.19",
            "DcCfg.PanLevMdul.SwRev.20",
            "DcCfg.PanLevMdul.SwRev.21",
            "DcCfg.PanLevMdul.SwRev.22",
            "DcCfg.PanLevMdul.SwRev.23",
            "DcCfg.PanLevMdul.SwRev.24",
            "DcCfg.PanLevMdul.SwRev.25",
            "DcCfg.PanLevMdul.SwRev.26",
            "DcCfg.PanLevMdul.SwRev.27",
            "DcCfg.PanLevMdul.SwRev.28",
            "DcCfg.PanLevMdul.SwRev.29",
            "DcCfg.PanLevMdul.SwRev.30",
            "DcCfg.PanLevMdul.SwRev.31",
            "DcCfg.PanLevMdul.SwRev.32",
            "DcCfg.PanLevMdul.SwRev.33",
            "DcCfg.PanLevMdul.SwRev.34",
            "DcCfg.PanLevMdul.SwRev.35",
            "DcCfg.PanLevMdul.SwRev.36",
            "DcCfg.PanLevMdul.SwRev.37",
            "DcCfg.PanLevMdul.SwRev.38",
            "DcCfg.PanLevMdul.SwRev.39",
            "DcCfg.PanLevMdul.SwRev.40",
            "DcCfg.PanLevMdul.SwRev.41",
            "DcCfg.PanLevMdul.SwRev.42",
            "DcCfg.PanLevMdul.SwRev.43",
            "DcCfg.PanLevMdul.SwRev.44",
            "DcCfg.PanLevMdul.SwRev.45",
            "DcCfg.PanLevMdul.SwRev.46",
            "DcCfg.PanLevMdul.SwRev.47",
            "DcCfg.PanLevMdul.SwRev.48",
            "DcCfg.PanLevMdul.SwRev.49",
            "DcCfg.PanLevMdul.SwRev.50",
            "DcCfg.PanLevMdul.SwRev.51",
            "DcCfg.PanLevMdul.SwRev.52",
            "DcCfg.PanLevMdul.SwRev.53",
            "DcCfg.PanLevMdul.SwRev.54",
            "DcCfg.PanLevMdul.SwRev.55",
            "DcCfg.PanLevMdul.SwRev.56",
            "DcCfg.PanLevMdul.SwRev.57",
            "DcCfg.PanLevMdul.SwRev.58",
            "DcCfg.PanLevMdul.SwRev.59",
            "DcCfg.PanLevMdul.SwRev.60",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.4",
            "Eth.Proxy.Port",
            "DcCfg.MPPShdw.CycTms",
            "Inverter.VArModCfg.PFCfg.Dyn.VArTms",
            "Inverter.WModCfg.WCtlVolCfg.Crv.NumPt",
            "Inverter.VArModCfg.VArModIn",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WTmEna",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArTmEna",
            "Eth.Proxy.Pwd",
            "Mb.UdpSrv.Port",
            "Inverter.VAMaxOutRtg",
            "Inverter.FltAMod",
            "Inverter.WGraMppEna",
            "Inverter.WModCfg.WCtlVolCfg.Ena",
            "DtTm.DlSvIsOn",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraPos",
            "Inverter.WModCfg.WCtlComCfg2.LoPrioEna",
            "GridGuard.Cntry.FrqCtl.ConnMin",
            "Wl.ActlIp",
            "DcCfg.PanLevCom.SwRev.1",
            "DcCfg.PanLevCom.SwRev.2",
            "DcCfg.PanLevCom.SwRev.3",
            "DcCfg.PanLevCom.SwRev.4",
            "Inverter.VArModCfg.ImpCpn.IsOn",
            "Inverter.VArMaxZerWQ1",
            "Inverter.CtlComCfg.PFCtlCom.CtlComMssMod",
            "Acs.PwdUsr",
            "Inverter.PlntCtl.VRefMod",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.NumPt",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HystEnaOv",
            "DcCfg.PanLevCom.HwRev.1",
            "DcCfg.PanLevCom.HwRev.2",
            "DcCfg.PanLevCom.HwRev.3",
            "DcCfg.PanLevCom.HwRev.4",
            "GridGuard.Cntry.AMaxOfsMod",
            "GridGuard.Cntry.VolCtl.llLimTmms",
            "Nameplate.CmpMain.SerNum",
            "Nameplate.CmpOS.SwRev",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraPos",
            "WebConn.IsOn",
            "DcCfg.PanLevStrg.MdulCnt.1",
            "DcCfg.PanLevStrg.MdulCnt.2",
            "DcCfg.PanLevStrg.MdulCnt.3",
            "DcCfg.PanLevStrg.MdulCnt.4",
            "DcCfg.PanLevStrg.MdulCnt.5",
            "DcCfg.PanLevStrg.MdulCnt.6",
            "DcCfg.PanLevStrg.MdulCnt.7",
            "DcCfg.PanLevStrg.MdulCnt.8",
            "DcCfg.PanLevStrg.MdulCnt.9",
            "DcCfg.PanLevStrg.MdulCnt.10",
            "Inverter.VArMaxZerWQ2",
            "GridGuard.Cntry.FrqCtl.MaxTmms",
            "Mb.UdpSrv.IsOn",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.4",
            "Inverter.CtlComCfg.WCtlCom2.CtlComMssMod",
            "Inverter.VArMaxQ4Rtg",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArTms",
            "DcCfg.PanLevCom.GwCnt",
            "Inverter.WMax",
            "Inverter.VArMaxZerWQ3",
            "Inverter.VArModCfg.HystTms",
            "GridGuard.Cntry.VolCtl.MaxPuTmms",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArTmEna",
            "DcCfg.ConstVolCtl.Vset.1",
            "DcCfg.ConstVolCtl.Vset.2",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFExt",
            "DcCfg.PanLevStrg.MPPTrk.1",
            "DcCfg.PanLevStrg.MPPTrk.2",
            "DcCfg.PanLevStrg.MPPTrk.3",
            "DcCfg.PanLevStrg.MPPTrk.4",
            "DcCfg.PanLevStrg.MPPTrk.5",
            "DcCfg.PanLevStrg.MPPTrk.6",
            "DcCfg.PanLevStrg.MPPTrk.7",
            "DcCfg.PanLevStrg.MPPTrk.8",
            "DcCfg.PanLevStrg.MPPTrk.9",
            "DcCfg.PanLevStrg.MPPTrk.10",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.DsaUnVolPu",
            "GridGuard.Cntry.FrqCtl.MinTmms",
            "Inverter.VArModCfg.VArModZerWFlb",
            "SwCmp.CmpWebUsrItf.SwRev",
            "Inverter.VArModCfg.VArCnstCfgIn.VArNom",
            "Wl.Sec.Cry",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraNeg",
            "Spdwr.Ip",
            "Inverter.DGSModCfg.DGSMod",
            "Inverter.DGSModCfg.AvLtTms",
            "PCC.WMaxNom",
            "Metering.TotFeedTmhSet",
            "Nameplate.CmpMain.HwVer",
            "GridGuard.Cntry.VolCtl.ConnMinPu",
            "Inverter.VAMaxInRtg",
            "Inverter.VArMaxQ1",
            "Mb.SunSpec.MdbPrflRev",
            "GridGuard.Cntry.FrqCtl.SwMinTmms",
            "GridGuard.Cntry.Aid.HzMon.HzMonTmms",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HystEnaUn",
            "Inverter.ASTTypeRO",
            "DcCfg.StrTms.1",
            "DcCfg.StrTms.2",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArTmEna",
            "PCC.WMax",
            "GridGuard.Cntry.VolCtl.hLimPu",
            "Inverter.VArModCfg.VArCfg.Dyn.VArTmEna",
            "Inverter.PFMinQ2Rtg",
            "Spdwr.GwIp",
            "Coolsys.FanTst",
            "Inverter.VArMaxQ2",
            "GridGuard.Cntry.VolCtl.MinPu",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.NumPtMax",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WTms",
            "Inverter.VArGraConnEna",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFExtIn",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArTms",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraPos",
            "Inverter.WModCfg.WCnstCfg.WNom",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.VArModOut",
            "Inverter.WCtlHzModCfg.RefModUn",
            "Spdwr.ActlDnsSrvIp",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.AutnAdjMod",
            "Inverter.DGSModCfg.VRefThMod",
            "Wl.ActlGwIp",
            "PCC.FlbInv.WMax",
            "Inverter.WCtlHzModCfg.WTms",
            "RS485.RS485Mod",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.4",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.5",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.6",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.7",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.8",
            "Inverter.CtlComCfg.VArCtlVolCom.CtlComMssMod",
            "Inverter.WMaxInRtg",
            "GridGuard.Cntry.VolCtl.MaxPu",
            "Mb.TcpSrv.IsOn",
            "Inverter.VArModCfg.VArCnstCfg.VArNom",
            "GridGuard.Cntry",
            "GridGuard.Cntry.AMaxOfs",
            "GridGuard.Cntry.LeakRisMin",
            "DcCfg.PanLevCtl.Model",
            "GridGuard.Cntry.GriFltTms",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WTmEna",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.3",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.4",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.NumPt",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraNeg",
            "Inverter.WGraConn",
            "GridGuard.Cntry.FrqCtl.Max",
            "Wl.Ip",
            "SwCmp.CmpTmZn.SwRev",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.4",
            "DcCfg.PanLevMdul.Model.1",
            "DcCfg.PanLevMdul.Model.2",
            "DcCfg.PanLevMdul.Model.3",
            "DcCfg.PanLevMdul.Model.4",
            "DcCfg.PanLevMdul.Model.5",
            "DcCfg.PanLevMdul.Model.6",
            "DcCfg.PanLevMdul.Model.7",
            "DcCfg.PanLevMdul.Model.8",
            "DcCfg.PanLevMdul.Model.9",
            "DcCfg.PanLevMdul.Model.10",
            "DcCfg.PanLevMdul.Model.11",
            "DcCfg.PanLevMdul.Model.12",
            "DcCfg.PanLevMdul.Model.13",
            "DcCfg.PanLevMdul.Model.14",
            "DcCfg.PanLevMdul.Model.15",
            "DcCfg.PanLevMdul.Model.16",
            "DcCfg.PanLevMdul.Model.17",
            "DcCfg.PanLevMdul.Model.18",
            "DcCfg.PanLevMdul.Model.19",
            "DcCfg.PanLevMdul.Model.20",
            "DcCfg.PanLevMdul.Model.21",
            "DcCfg.PanLevMdul.Model.22",
            "DcCfg.PanLevMdul.Model.23",
            "DcCfg.PanLevMdul.Model.24",
            "DcCfg.PanLevMdul.Model.25",
            "DcCfg.PanLevMdul.Model.26",
            "DcCfg.PanLevMdul.Model.27",
            "DcCfg.PanLevMdul.Model.28",
            "DcCfg.PanLevMdul.Model.29",
            "DcCfg.PanLevMdul.Model.30",
            "DcCfg.PanLevMdul.Model.31",
            "DcCfg.PanLevMdul.Model.32",
            "DcCfg.PanLevMdul.Model.33",
            "DcCfg.PanLevMdul.Model.34",
            "DcCfg.PanLevMdul.Model.35",
            "DcCfg.PanLevMdul.Model.36",
            "DcCfg.PanLevMdul.Model.37",
            "DcCfg.PanLevMdul.Model.38",
            "DcCfg.PanLevMdul.Model.39",
            "DcCfg.PanLevMdul.Model.40",
            "DcCfg.PanLevMdul.Model.41",
            "DcCfg.PanLevMdul.Model.42",
            "DcCfg.PanLevMdul.Model.43",
            "DcCfg.PanLevMdul.Model.44",
            "DcCfg.PanLevMdul.Model.45",
            "DcCfg.PanLevMdul.Model.46",
            "DcCfg.PanLevMdul.Model.47",
            "DcCfg.PanLevMdul.Model.48",
            "DcCfg.PanLevMdul.Model.49",
            "DcCfg.PanLevMdul.Model.50",
            "DcCfg.PanLevMdul.Model.51",
            "DcCfg.PanLevMdul.Model.52",
            "DcCfg.PanLevMdul.Model.53",
            "DcCfg.PanLevMdul.Model.54",
            "DcCfg.PanLevMdul.Model.55",
            "DcCfg.PanLevMdul.Model.56",
            "DcCfg.PanLevMdul.Model.57",
            "DcCfg.PanLevMdul.Model.58",
            "DcCfg.PanLevMdul.Model.59",
            "DcCfg.PanLevMdul.Model.60",
            "Nameplate.CmpCom.SwRev",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraEna",
            "Metering.GridMs.TotkWhOutOfs",
            "Inverter.PFMinQ1Rtg",
            "GridGuard.Cntry.FrqCtl.ReconMin",
            "Sys.SelfTstDmd",
            "Inverter.VArModCfg.PFCfg.Dyn.VArTmEna",
            "Inverter.WCtlHzModCfg.Ena",
            "Inverter.VArModCfg.PFMinEna",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraEna",
            "Spdwr.IgmpQryTx",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.WFilTms",
            "PvGen.PvWhSet",
            "Inverter.VArModCfg.ImpCpn.OhmRis",
            "Inverter.WModCfg.WCtlVolCfg.WGraPos",
            "DcCfg.PanLevStrg.OptCnt.1",
            "DcCfg.PanLevStrg.OptCnt.2",
            "DcCfg.PanLevStrg.OptCnt.3",
            "DcCfg.PanLevStrg.OptCnt.4",
            "DcCfg.PanLevStrg.OptCnt.5",
            "DcCfg.PanLevStrg.OptCnt.6",
            "DcCfg.PanLevStrg.OptCnt.7",
            "DcCfg.PanLevStrg.OptCnt.8",
            "DcCfg.PanLevStrg.OptCnt.9",
            "DcCfg.PanLevStrg.OptCnt.10",
            "Inverter.CtlComCfg.WCtlCom.FlbWMax",
            "Metering.Mb.EnMtrSerNumTxt",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.3",
            "Inverter.CtlComCfg.WCtlCom2.TmsOut",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.4",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.5",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.6",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.7",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.8",
            "Sys.EthDiag",
            "GridGuard.Cntry.VRtg",
            "Inverter.DGSModCfg.HystVolPu",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.4",
            "GridGuard.Cntry.FrqCtl.lLim",
            "IecCfg.GoCfg.GoMacId",
            "Inverter.VArMaxQ3",
            "Wl.IsOn",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.WFilTmEna",
            "Wl.ExsNetw.1",
            "Wl.ExsNetw.2",
            "Wl.ExsNetw.3",
            "Inverter.WModCfg.WCtlVolCfg.WGraNeg",
            "Eth.Proxy.Srv",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraEna",
            "Mb.TcpSrv.Port",
            "Wl.GwIp",
            "Inverter.VArMaxQ4",
            "DcMs.Amp.1",
            "DcMs.Amp.2",
            "DcMs.PanLevCtl.CfgStt",
            "DcMs.PanLevMdul.Amp.1",
            "DcMs.PanLevMdul.Amp.2",
            "DcMs.PanLevMdul.Amp.3",
            "DcMs.PanLevMdul.Amp.4",
            "DcMs.PanLevMdul.Amp.5",
            "DcMs.PanLevMdul.Amp.6",
            "DcMs.PanLevMdul.Amp.7",
            "DcMs.PanLevMdul.Amp.8",
            "DcMs.PanLevMdul.Amp.9",
            "DcMs.PanLevMdul.Amp.10",
            "DcMs.PanLevMdul.Amp.11",
            "DcMs.PanLevMdul.Amp.12",
            "DcMs.PanLevMdul.Amp.13",
            "DcMs.PanLevMdul.Amp.14",
            "DcMs.PanLevMdul.Amp.15",
            "DcMs.PanLevMdul.Amp.16",
            "DcMs.PanLevMdul.Amp.17",
            "DcMs.PanLevMdul.Amp.18",
            "DcMs.PanLevMdul.Amp.19",
            "DcMs.PanLevMdul.Amp.20",
            "DcMs.PanLevMdul.Amp.21",
            "DcMs.PanLevMdul.Amp.22",
            "DcMs.PanLevMdul.Amp.23",
            "DcMs.PanLevMdul.Amp.24",
            "DcMs.PanLevMdul.Amp.25",
            "DcMs.PanLevMdul.Amp.26",
            "DcMs.PanLevMdul.Amp.27",
            "DcMs.PanLevMdul.Amp.28",
            "DcMs.PanLevMdul.Amp.29",
            "DcMs.PanLevMdul.Amp.30",
            "DcMs.PanLevMdul.Amp.31",
            "DcMs.PanLevMdul.Amp.32",
            "DcMs.PanLevMdul.Amp.33",
            "DcMs.PanLevMdul.Amp.34",
            "DcMs.PanLevMdul.Amp.35",
            "DcMs.PanLevMdul.Amp.36",
            "DcMs.PanLevMdul.Amp.37",
            "DcMs.PanLevMdul.Amp.38",
            "DcMs.PanLevMdul.Amp.39",
            "DcMs.PanLevMdul.Amp.40",
            "DcMs.PanLevMdul.Amp.41",
            "DcMs.PanLevMdul.Amp.42",
            "DcMs.PanLevMdul.Amp.43",
            "DcMs.PanLevMdul.Amp.44",
            "DcMs.PanLevMdul.Amp.45",
            "DcMs.PanLevMdul.Amp.46",
            "DcMs.PanLevMdul.Amp.47",
            "DcMs.PanLevMdul.Amp.48",
            "DcMs.PanLevMdul.Amp.49",
            "DcMs.PanLevMdul.Amp.50",
            "DcMs.PanLevMdul.Amp.51",
            "DcMs.PanLevMdul.Amp.52",
            "DcMs.PanLevMdul.Amp.53",
            "DcMs.PanLevMdul.Amp.54",
            "DcMs.PanLevMdul.Amp.55",
            "DcMs.PanLevMdul.Amp.56",
            "DcMs.PanLevMdul.Amp.57",
            "DcMs.PanLevMdul.Amp.58",
            "DcMs.PanLevMdul.Amp.59",
            "DcMs.PanLevMdul.Amp.60",
            "DcMs.PanLevMdul.SigPwr.1",
            "DcMs.PanLevMdul.SigPwr.2",
            "DcMs.PanLevMdul.SigPwr.3",
            "DcMs.PanLevMdul.SigPwr.4",
            "DcMs.PanLevMdul.SigPwr.5",
            "DcMs.PanLevMdul.SigPwr.6",
            "DcMs.PanLevMdul.SigPwr.7",
            "DcMs.PanLevMdul.SigPwr.8",
            "DcMs.PanLevMdul.SigPwr.9",
            "DcMs.PanLevMdul.SigPwr.10",
            "DcMs.PanLevMdul.SigPwr.11",
            "DcMs.PanLevMdul.SigPwr.12",
            "DcMs.PanLevMdul.SigPwr.13",
            "DcMs.PanLevMdul.SigPwr.14",
            "DcMs.PanLevMdul.SigPwr.15",
            "DcMs.PanLevMdul.SigPwr.16",
            "DcMs.PanLevMdul.SigPwr.17",
            "DcMs.PanLevMdul.SigPwr.18",
            "DcMs.PanLevMdul.SigPwr.19",
            "DcMs.PanLevMdul.SigPwr.20",
            "DcMs.PanLevMdul.SigPwr.21",
            "DcMs.PanLevMdul.SigPwr.22",
            "DcMs.PanLevMdul.SigPwr.23",
            "DcMs.PanLevMdul.SigPwr.24",
            "DcMs.PanLevMdul.SigPwr.25",
            "DcMs.PanLevMdul.SigPwr.26",
            "DcMs.PanLevMdul.SigPwr.27",
            "DcMs.PanLevMdul.SigPwr.28",
            "DcMs.PanLevMdul.SigPwr.29",
            "DcMs.PanLevMdul.SigPwr.30",
            "DcMs.PanLevMdul.SigPwr.31",
            "DcMs.PanLevMdul.SigPwr.32",
            "DcMs.PanLevMdul.SigPwr.33",
            "DcMs.PanLevMdul.SigPwr.34",
            "DcMs.PanLevMdul.SigPwr.35",
            "DcMs.PanLevMdul.SigPwr.36",
            "DcMs.PanLevMdul.SigPwr.37",
            "DcMs.PanLevMdul.SigPwr.38",
            "DcMs.PanLevMdul.SigPwr.39",
            "DcMs.PanLevMdul.SigPwr.40",
            "DcMs.PanLevMdul.SigPwr.41",
            "DcMs.PanLevMdul.SigPwr.42",
            "DcMs.PanLevMdul.SigPwr.43",
            "DcMs.PanLevMdul.SigPwr.44",
            "DcMs.PanLevMdul.SigPwr.45",
            "DcMs.PanLevMdul.SigPwr.46",
            "DcMs.PanLevMdul.SigPwr.47",
            "DcMs.PanLevMdul.SigPwr.48",
            "DcMs.PanLevMdul.SigPwr.49",
            "DcMs.PanLevMdul.SigPwr.50",
            "DcMs.PanLevMdul.SigPwr.51",
            "DcMs.PanLevMdul.SigPwr.52",
            "DcMs.PanLevMdul.SigPwr.53",
            "DcMs.PanLevMdul.SigPwr.54",
            "DcMs.PanLevMdul.SigPwr.55",
            "DcMs.PanLevMdul.SigPwr.56",
            "DcMs.PanLevMdul.SigPwr.57",
            "DcMs.PanLevMdul.SigPwr.58",
            "DcMs.PanLevMdul.SigPwr.59",
            "DcMs.PanLevMdul.SigPwr.60",
            "DcMs.PanLevMdul.Tmp.1",
            "DcMs.PanLevMdul.Tmp.2",
            "DcMs.PanLevMdul.Tmp.3",
            "DcMs.PanLevMdul.Tmp.4",
            "DcMs.PanLevMdul.Tmp.5",
            "DcMs.PanLevMdul.Tmp.6",
            "DcMs.PanLevMdul.Tmp.7",
            "DcMs.PanLevMdul.Tmp.8",
            "DcMs.PanLevMdul.Tmp.9",
            "DcMs.PanLevMdul.Tmp.10",
            "DcMs.PanLevMdul.Tmp.11",
            "DcMs.PanLevMdul.Tmp.12",
            "DcMs.PanLevMdul.Tmp.13",
            "DcMs.PanLevMdul.Tmp.14",
            "DcMs.PanLevMdul.Tmp.15",
            "DcMs.PanLevMdul.Tmp.16",
            "DcMs.PanLevMdul.Tmp.17",
            "DcMs.PanLevMdul.Tmp.18",
            "DcMs.PanLevMdul.Tmp.19",
            "DcMs.PanLevMdul.Tmp.20",
            "DcMs.PanLevMdul.Tmp.21",
            "DcMs.PanLevMdul.Tmp.22",
            "DcMs.PanLevMdul.Tmp.23",
            "DcMs.PanLevMdul.Tmp.24",
            "DcMs.PanLevMdul.Tmp.25",
            "DcMs.PanLevMdul.Tmp.26",
            "DcMs.PanLevMdul.Tmp.27",
            "DcMs.PanLevMdul.Tmp.28",
            "DcMs.PanLevMdul.Tmp.29",
            "DcMs.PanLevMdul.Tmp.30",
            "DcMs.PanLevMdul.Tmp.31",
            "DcMs.PanLevMdul.Tmp.32",
            "DcMs.PanLevMdul.Tmp.33",
            "DcMs.PanLevMdul.Tmp.34",
            "DcMs.PanLevMdul.Tmp.35",
            "DcMs.PanLevMdul.Tmp.36",
            "DcMs.PanLevMdul.Tmp.37",
            "DcMs.PanLevMdul.Tmp.38",
            "DcMs.PanLevMdul.Tmp.39",
            "DcMs.PanLevMdul.Tmp.40",
            "DcMs.PanLevMdul.Tmp.41",
            "DcMs.PanLevMdul.Tmp.42",
            "DcMs.PanLevMdul.Tmp.43",
            "DcMs.PanLevMdul.Tmp.44",
            "DcMs.PanLevMdul.Tmp.45",
            "DcMs.PanLevMdul.Tmp.46",
            "DcMs.PanLevMdul.Tmp.47",
            "DcMs.PanLevMdul.Tmp.48",
            "DcMs.PanLevMdul.Tmp.49",
            "DcMs.PanLevMdul.Tmp.50",
            "DcMs.PanLevMdul.Tmp.51",
            "DcMs.PanLevMdul.Tmp.52",
            "DcMs.PanLevMdul.Tmp.53",
            "DcMs.PanLevMdul.Tmp.54",
            "DcMs.PanLevMdul.Tmp.55",
            "DcMs.PanLevMdul.Tmp.56",
            "DcMs.PanLevMdul.Tmp.57",
            "DcMs.PanLevMdul.Tmp.58",
            "DcMs.PanLevMdul.Tmp.59",
            "DcMs.PanLevMdul.Tmp.60",
            "DcMs.PanLevMdul.Vol.1",
            "DcMs.PanLevMdul.Vol.2",
            "DcMs.PanLevMdul.Vol.3",
            "DcMs.PanLevMdul.Vol.4",
            "DcMs.PanLevMdul.Vol.5",
            "DcMs.PanLevMdul.Vol.6",
            "DcMs.PanLevMdul.Vol.7",
            "DcMs.PanLevMdul.Vol.8",
            "DcMs.PanLevMdul.Vol.9",
            "DcMs.PanLevMdul.Vol.10",
            "DcMs.PanLevMdul.Vol.11",
            "DcMs.PanLevMdul.Vol.12",
            "DcMs.PanLevMdul.Vol.13",
            "DcMs.PanLevMdul.Vol.14",
            "DcMs.PanLevMdul.Vol.15",
            "DcMs.PanLevMdul.Vol.16",
            "DcMs.PanLevMdul.Vol.17",
            "DcMs.PanLevMdul.Vol.18",
            "DcMs.PanLevMdul.Vol.19",
            "DcMs.PanLevMdul.Vol.20",
            "DcMs.PanLevMdul.Vol.21",
            "DcMs.PanLevMdul.Vol.22",
            "DcMs.PanLevMdul.Vol.23",
            "DcMs.PanLevMdul.Vol.24",
            "DcMs.PanLevMdul.Vol.25",
            "DcMs.PanLevMdul.Vol.26",
            "DcMs.PanLevMdul.Vol.27",
            "DcMs.PanLevMdul.Vol.28",
            "DcMs.PanLevMdul.Vol.29",
            "DcMs.PanLevMdul.Vol.30",
            "DcMs.PanLevMdul.Vol.31",
            "DcMs.PanLevMdul.Vol.32",
            "DcMs.PanLevMdul.Vol.33",
            "DcMs.PanLevMdul.Vol.34",
            "DcMs.PanLevMdul.Vol.35",
            "DcMs.PanLevMdul.Vol.36",
            "DcMs.PanLevMdul.Vol.37",
            "DcMs.PanLevMdul.Vol.38",
            "DcMs.PanLevMdul.Vol.39",
            "DcMs.PanLevMdul.Vol.40",
            "DcMs.PanLevMdul.Vol.41",
            "DcMs.PanLevMdul.Vol.42",
            "DcMs.PanLevMdul.Vol.43",
            "DcMs.PanLevMdul.Vol.44",
            "DcMs.PanLevMdul.Vol.45",
            "DcMs.PanLevMdul.Vol.46",
            "DcMs.PanLevMdul.Vol.47",
            "DcMs.PanLevMdul.Vol.48",
            "DcMs.PanLevMdul.Vol.49",
            "DcMs.PanLevMdul.Vol.50",
            "DcMs.PanLevMdul.Vol.51",
            "DcMs.PanLevMdul.Vol.52",
            "DcMs.PanLevMdul.Vol.53",
            "DcMs.PanLevMdul.Vol.54",
            "DcMs.PanLevMdul.Vol.55",
            "DcMs.PanLevMdul.Vol.56",
            "DcMs.PanLevMdul.Vol.57",
            "DcMs.PanLevMdul.Vol.58",
            "DcMs.PanLevMdul.Vol.59",
            "DcMs.PanLevMdul.Vol.60",
            "DcMs.PanLevMdul.Watt.1",
            "DcMs.PanLevMdul.Watt.2",
            "DcMs.PanLevMdul.Watt.3",
            "DcMs.PanLevMdul.Watt.4",
            "DcMs.PanLevMdul.Watt.5",
            "DcMs.PanLevMdul.Watt.6",
            "DcMs.PanLevMdul.Watt.7",
            "DcMs.PanLevMdul.Watt.8",
            "DcMs.PanLevMdul.Watt.9",
            "DcMs.PanLevMdul.Watt.10",
            "DcMs.PanLevMdul.Watt.11",
            "DcMs.PanLevMdul.Watt.12",
            "DcMs.PanLevMdul.Watt.13",
            "DcMs.PanLevMdul.Watt.14",
            "DcMs.PanLevMdul.Watt.15",
            "DcMs.PanLevMdul.Watt.16",
            "DcMs.PanLevMdul.Watt.17",
            "DcMs.PanLevMdul.Watt.18",
            "DcMs.PanLevMdul.Watt.19",
            "DcMs.PanLevMdul.Watt.20",
            "DcMs.PanLevMdul.Watt.21",
            "DcMs.PanLevMdul.Watt.22",
            "DcMs.PanLevMdul.Watt.23",
            "DcMs.PanLevMdul.Watt.24",
            "DcMs.PanLevMdul.Watt.25",
            "DcMs.PanLevMdul.Watt.26",
            "DcMs.PanLevMdul.Watt.27",
            "DcMs.PanLevMdul.Watt.28",
            "DcMs.PanLevMdul.Watt.29",
            "DcMs.PanLevMdul.Watt.30",
            "DcMs.PanLevMdul.Watt.31",
            "DcMs.PanLevMdul.Watt.32",
            "DcMs.PanLevMdul.Watt.33",
            "DcMs.PanLevMdul.Watt.34",
            "DcMs.PanLevMdul.Watt.35",
            "DcMs.PanLevMdul.Watt.36",
            "DcMs.PanLevMdul.Watt.37",
            "DcMs.PanLevMdul.Watt.38",
            "DcMs.PanLevMdul.Watt.39",
            "DcMs.PanLevMdul.Watt.40",
            "DcMs.PanLevMdul.Watt.41",
            "DcMs.PanLevMdul.Watt.42",
            "DcMs.PanLevMdul.Watt.43",
            "DcMs.PanLevMdul.Watt.44",
            "DcMs.PanLevMdul.Watt.45",
            "DcMs.PanLevMdul.Watt.46",
            "DcMs.PanLevMdul.Watt.47",
            "DcMs.PanLevMdul.Watt.48",
            "DcMs.PanLevMdul.Watt.49",
            "DcMs.PanLevMdul.Watt.50",
            "DcMs.PanLevMdul.Watt.51",
            "DcMs.PanLevMdul.Watt.52",
            "DcMs.PanLevMdul.Watt.53",
            "DcMs.PanLevMdul.Watt.54",
            "DcMs.PanLevMdul.Watt.55",
            "DcMs.PanLevMdul.Watt.56",
            "DcMs.PanLevMdul.Watt.57",
            "DcMs.PanLevMdul.Watt.58",
            "DcMs.PanLevMdul.Watt.59",
            "DcMs.PanLevMdul.Watt.60",
            "DcMs.Vol.1",
            "DcMs.Vol.2",
            "DcMs.Watt.1",
            "DcMs.Watt.2",
            "GridGuard.Cntry.1",
            "GridGuard.Cntry.2",
            "GridMs.A.phsA",
            "GridMs.Hz",
            "GridMs.PhV.phsA",
            "GridMs.TotA",
            "GridMs.TotPFEEI",
            "GridMs.TotPFExt",
            "GridMs.TotPFPrc",
            "GridMs.TotVA",
            "GridMs.TotVAr",
            "GridMs.TotVAr.Pv",
            "GridMs.TotW",
            "GridMs.TotW.Pv",
            "GridMs.VA.phsA",
            "GridMs.VAr.phsA",
            "GridMs.W.phsA",
            "Inverter.SwAfciCnt",
            "Isolation.FltA",
            "Isolation.LeakRis",
            "Metering.DyWhOut",
            "Metering.Mb.EnMtrTyp",
            "Metering.Mb.Health",
            "Metering.TotFeedTms",
            "Metering.TotOpTms",
            "Metering.TotWhOut",
            "Metering.TotWhOut.Pv",
            "Operation.BckStt",
            "Operation.DrtStt",
            "Operation.Evt.Dsc",
            "Operation.Evt.Msg",
            "Operation.Evt.Prio",
            "Operation.EvtCntIstl",
            "Operation.EvtCntUsr",
            "Operation.GriSwCnt",
            "Operation.GriSwStt",
            "Operation.Health",
            "Operation.HealthStt.Alm",
            "Operation.HealthStt.Ok",
            "Operation.HealthStt.Wrn",
            "Operation.Inverter.Health",
            "Operation.OpStt",
            "Operation.PanLevCom.Health.1",
            "Operation.PanLevCom.Health.2",
            "Operation.PanLevCom.Health.3",
            "Operation.PanLevCom.Health.4",
            "Operation.PanLevCtl.Health",
            "Operation.PanLevMdul.Health.1",
            "Operation.PanLevMdul.Health.2",
            "Operation.PanLevMdul.Health.3",
            "Operation.PanLevMdul.Health.4",
            "Operation.PanLevMdul.Health.5",
            "Operation.PanLevMdul.Health.6",
            "Operation.PanLevMdul.Health.7",
            "Operation.PanLevMdul.Health.8",
            "Operation.PanLevMdul.Health.9",
            "Operation.PanLevMdul.Health.10",
            "Operation.PanLevMdul.Health.11",
            "Operation.PanLevMdul.Health.12",
            "Operation.PanLevMdul.Health.13",
            "Operation.PanLevMdul.Health.14",
            "Operation.PanLevMdul.Health.15",
            "Operation.PanLevMdul.Health.16",
            "Operation.PanLevMdul.Health.17",
            "Operation.PanLevMdul.Health.18",
            "Operation.PanLevMdul.Health.19",
            "Operation.PanLevMdul.Health.20",
            "Operation.PanLevMdul.Health.21",
            "Operation.PanLevMdul.Health.22",
            "Operation.PanLevMdul.Health.23",
            "Operation.PanLevMdul.Health.24",
            "Operation.PanLevMdul.Health.25",
            "Operation.PanLevMdul.Health.26",
            "Operation.PanLevMdul.Health.27",
            "Operation.PanLevMdul.Health.28",
            "Operation.PanLevMdul.Health.29",
            "Operation.PanLevMdul.Health.30",
            "Operation.PanLevMdul.Health.31",
            "Operation.PanLevMdul.Health.32",
            "Operation.PanLevMdul.Health.33",
            "Operation.PanLevMdul.Health.34",
            "Operation.PanLevMdul.Health.35",
            "Operation.PanLevMdul.Health.36",
            "Operation.PanLevMdul.Health.37",
            "Operation.PanLevMdul.Health.38",
            "Operation.PanLevMdul.Health.39",
            "Operation.PanLevMdul.Health.40",
            "Operation.PanLevMdul.Health.41",
            "Operation.PanLevMdul.Health.42",
            "Operation.PanLevMdul.Health.43",
            "Operation.PanLevMdul.Health.44",
            "Operation.PanLevMdul.Health.45",
            "Operation.PanLevMdul.Health.46",
            "Operation.PanLevMdul.Health.47",
            "Operation.PanLevMdul.Health.48",
            "Operation.PanLevMdul.Health.49",
            "Operation.PanLevMdul.Health.50",
            "Operation.PanLevMdul.Health.51",
            "Operation.PanLevMdul.Health.52",
            "Operation.PanLevMdul.Health.53",
            "Operation.PanLevMdul.Health.54",
            "Operation.PanLevMdul.Health.55",
            "Operation.PanLevMdul.Health.56",
            "Operation.PanLevMdul.Health.57",
            "Operation.PanLevMdul.Health.58",
            "Operation.PanLevMdul.Health.59",
            "Operation.PanLevMdul.Health.60",
            "Operation.PvGriConn",
            "Operation.VArCtl.VArModAct",
            "Operation.VArCtl.VArModStt",
            "Operation.WMaxLimSrc",
            "Operation.WMinLimSrc",
            "PvGen.PvW",
            "PvGen.PvWh",
            "Spdwr.ComSocA.ConnSpd",
            "Spdwr.ComSocA.DpxMode",
            "Spdwr.ComSocA.Stt",
            "Upd.Stt",
            "WebConn.Stt",
            "Wl.AcqStt",
            "Wl.ConnStt",
            "Wl.SigPwr",
            "Wl.SoftAcsConnStt",
            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
            "Operation.RSSOpMode",
            "Inverter.VArModCfg.PFCnstCfg.PFOut",
            "Metering.TotkWhOutSet",
            "Nameplate.CmpMain.SwRev",
            "GridGuard.Cntry.AMaxOfsNom",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.NumPtMax",
            "DtTm.TmZn",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnGra.3",
            "PCC.FlbInv.WMaxNom",
            "GridGuard.Cntry.VolCtl.ReconMaxPu",
            "Inverter.CtlComCfg.VArCtlVolCom.FlbVolRefPu",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.1",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.2",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.3",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.4",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.5",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.6",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.7",
            "Inverter.WModCfg.WCtlVolCfg.Crv.YVal.8",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.ActTms",
            "GridGuard.Cntry.PEOpnMon",
            "Inverter.WModCfg.GriSwOpnZerW",
            "Operation.CtrlType",
            "Inverter.VArModCfg.VArCfg.Dyn.VArTms",
            "Inverter.PFMinQ4Rtg",
            "Inverter.CtlComCfg.VArCtlCom.CtlComMssMod",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.4",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.5",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.6",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.7",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.8",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.9",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.10",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.11",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.XVal.12",
            "Inverter.VArModCfg.PFCnstCfg.PFIn",
            "Inverter.VArMaxQ1Rtg",
            "Inverter.CtlComCfg.PFCtlCom.FlbPF",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.WCtlTmms",
            "Inverter.WGraConnEna",
            "Nameplate.MainModel",
            "Wl.Sec.Psk",
            "Plnt.DcWRtg",
            "Nameplate.CmpCom.SusyId",
            "Inverter.WModCfg.WCnstCfg.W",
            "Spdwr.AutoCfgIsOn",
            "Inverter.VArModCfg.ImpCpn.CapacRis",
            "Acs.PwdIstl",
            "RS485.ConnSpd",
            "GridGuard.Cntry.VolCtl.RproPu",
            "Inverter.VArModCfg.InWNomLimAct",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzStopWGraTms",
            "Nameplate.SerNum",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraEna",
            "Inverter.VArModCfg.ImpCpn.InducRis",
            "Inverter.CtlComCfg.VArCtlCom.TmsOut",
            "Spdwr.ActlSnetMsk",
            "Metering.MsSpdwr.SerNumEN",
            "Inverter.VArModCfg.VArCnstCfg.VAr",
            "Upd.AutoUpdIsOn",
            "Inverter.WModCfg.WCtlVolCfg.ActTms",
            "GridGuard.Cntry.FrqCtl.SwMax",
            "Inverter.CtlComCfg.WCtlCom.FlbWMin",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.NumPtMax",
            "Inverter.WCtlHzModCfg.HzFilTmEna",
            "GridGuard.Cntry.VolCtl.MaxPeakPu",
            "GridGuard.Cntry.FrqCtl.SwMaxTmms",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraEna",
            "Inverter.DGSModCfg.ZerCurOvVolPu",
            "Wl.ActlSnetMsk",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.NumPt",
            "Inverter.WModCfg.WCtlVolCfg.Crv.NumPtMax",
            "Nameplate.CmpMain.Rev",
            "Spdwr.ActlIp",
            "Inverter.WModCfg.WMod",
            "Acs.Yap.SvcAllwdDt",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.DsaUnVolPu",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.AutnAdjTms",
            "Inverter.CtlComCfg.PFCtlCom.TmsOut",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraEna",
            "Inverter.VArModCfg.InWNomLimDeAct",
            "Inverter.WMaxIn",
            "PCC.EnMtrTmOut",
            "Nsd.ExsDev.1",
            "Nsd.ExsDev.2",
            "Nsd.ExsDev.3",
            "Nsd.ExsDev.4",
            "Nsd.ExsDev.5",
            "Nsd.ExsDev.6",
            "Nsd.ExsDev.7",
            "Nsd.ExsDev.8",
            "Nsd.ExsDev.9",
            "Nsd.ExsDev.10",
            "Nsd.ExsDev.11",
            "Nsd.ExsDev.12",
            "Nameplate.ARtg",
            "GridGuard.Cntry.VolCtl.ReconMinPu",
            "Metering.EnMtrARtg",
            "DtTm.NtpSrv",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WTms",
            "GridGuard.Cntry.FrqCtl.Min",
            "DcCfg.StrVol.1",
            "DcCfg.StrVol.2",
            "Inverter.PFMinQ3Rtg",
            "Eth.Proxy.IsOn",
            "Nameplate.ComRev",
            "Operation.SIS.IsOn",
            "Inverter.VArModCfg.VArModInFlb",
            "Nameplate.CmpCom.SerNum",
            "Wl.ActlDnsSrvIp",
            "Inverter.VArModCfg.VArCnstCfgIn.VAr",
            "GridGuard.Cntry.VolCtl.lLimPu",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUnStop",
            "GridGuard.Cntry.FrqCtl.ReconMax",
            "Spdwr.Cry",
            "Operation.BckOpMod",
            "Wl.DnsSrvIp",
            "Nameplate.MacId",
            "DcCfg.PanLevMdul.SerNum.1",
            "DcCfg.PanLevMdul.SerNum.2",
            "DcCfg.PanLevMdul.SerNum.3",
            "DcCfg.PanLevMdul.SerNum.4",
            "DcCfg.PanLevMdul.SerNum.5",
            "DcCfg.PanLevMdul.SerNum.6",
            "DcCfg.PanLevMdul.SerNum.7",
            "DcCfg.PanLevMdul.SerNum.8",
            "DcCfg.PanLevMdul.SerNum.9",
            "DcCfg.PanLevMdul.SerNum.10",
            "DcCfg.PanLevMdul.SerNum.11",
            "DcCfg.PanLevMdul.SerNum.12",
            "DcCfg.PanLevMdul.SerNum.13",
            "DcCfg.PanLevMdul.SerNum.14",
            "DcCfg.PanLevMdul.SerNum.15",
            "DcCfg.PanLevMdul.SerNum.16",
            "DcCfg.PanLevMdul.SerNum.17",
            "DcCfg.PanLevMdul.SerNum.18",
            "DcCfg.PanLevMdul.SerNum.19",
            "DcCfg.PanLevMdul.SerNum.20",
            "DcCfg.PanLevMdul.SerNum.21",
            "DcCfg.PanLevMdul.SerNum.22",
            "DcCfg.PanLevMdul.SerNum.23",
            "DcCfg.PanLevMdul.SerNum.24",
            "DcCfg.PanLevMdul.SerNum.25",
            "DcCfg.PanLevMdul.SerNum.26",
            "DcCfg.PanLevMdul.SerNum.27",
            "DcCfg.PanLevMdul.SerNum.28",
            "DcCfg.PanLevMdul.SerNum.29",
            "DcCfg.PanLevMdul.SerNum.30",
            "DcCfg.PanLevMdul.SerNum.31",
            "DcCfg.PanLevMdul.SerNum.32",
            "DcCfg.PanLevMdul.SerNum.33",
            "DcCfg.PanLevMdul.SerNum.34",
            "DcCfg.PanLevMdul.SerNum.35",
            "DcCfg.PanLevMdul.SerNum.36",
            "DcCfg.PanLevMdul.SerNum.37",
            "DcCfg.PanLevMdul.SerNum.38",
            "DcCfg.PanLevMdul.SerNum.39",
            "DcCfg.PanLevMdul.SerNum.40",
            "DcCfg.PanLevMdul.SerNum.41",
            "DcCfg.PanLevMdul.SerNum.42",
            "DcCfg.PanLevMdul.SerNum.43",
            "DcCfg.PanLevMdul.SerNum.44",
            "DcCfg.PanLevMdul.SerNum.45",
            "DcCfg.PanLevMdul.SerNum.46",
            "DcCfg.PanLevMdul.SerNum.47",
            "DcCfg.PanLevMdul.SerNum.48",
            "DcCfg.PanLevMdul.SerNum.49",
            "DcCfg.PanLevMdul.SerNum.50",
            "DcCfg.PanLevMdul.SerNum.51",
            "DcCfg.PanLevMdul.SerNum.52",
            "DcCfg.PanLevMdul.SerNum.53",
            "DcCfg.PanLevMdul.SerNum.54",
            "DcCfg.PanLevMdul.SerNum.55",
            "DcCfg.PanLevMdul.SerNum.56",
            "DcCfg.PanLevMdul.SerNum.57",
            "DcCfg.PanLevMdul.SerNum.58",
            "DcCfg.PanLevMdul.SerNum.59",
            "DcCfg.PanLevMdul.SerNum.60",
            "Plnt.VARtg",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.EnaVolPu",
            "Inverter.WCtlHzModCfg.RefModOv",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraNeg",
            "GridGuard.Cntry.VolCtl.ConnMaxPu",
            "Inverter.PFMinQ4",
            "Mb.UntId",
            "Inverter.VArGraConn",
            "Spdwr.IgmpQryTms",
            "Inverter.WGraReconEna",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArTmsPrc",
            "Inverter.VArLimVolCfg.Ena",
            "Sys.ComDiag",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraNeg",
            "Inverter.PFMinQ3",
            "GridGuard.Cntry.VolCtl.hhLimPu",
            "CntrySettings.Lang",
            "Operation.OpMod",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.DsaVolPu",
            "RS485.Term",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.ActTms",
            "Nameplate.Location",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraEna",
            "Inverter.VArMaxQ3Rtg",
            "Inverter.PFMinQ2",
            "GridGuard.Cntry.VolCtl.RproTmms",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraEna",
            "GridGuard.Cntry.VolCtl.hLimTmms",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzStopWGra",
            "Inverter.VArModCfg.PFCfg.Dyn.WFilTmEna",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOv.3",
            "Inverter.VArModCfg.VArNomRefMod",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PFExt.3",
            "Acs.Yap.SvcIsAllwd",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraNeg",
            "DcCfg.PanLevMdul.Lbl.1",
            "DcCfg.PanLevMdul.Lbl.2",
            "DcCfg.PanLevMdul.Lbl.3",
            "DcCfg.PanLevMdul.Lbl.4",
            "DcCfg.PanLevMdul.Lbl.5",
            "DcCfg.PanLevMdul.Lbl.6",
            "DcCfg.PanLevMdul.Lbl.7",
            "DcCfg.PanLevMdul.Lbl.8",
            "DcCfg.PanLevMdul.Lbl.9",
            "DcCfg.PanLevMdul.Lbl.10",
            "DcCfg.PanLevMdul.Lbl.11",
            "DcCfg.PanLevMdul.Lbl.12",
            "DcCfg.PanLevMdul.Lbl.13",
            "DcCfg.PanLevMdul.Lbl.14",
            "DcCfg.PanLevMdul.Lbl.15",
            "DcCfg.PanLevMdul.Lbl.16",
            "DcCfg.PanLevMdul.Lbl.17",
            "DcCfg.PanLevMdul.Lbl.18",
            "DcCfg.PanLevMdul.Lbl.19",
            "DcCfg.PanLevMdul.Lbl.20",
            "DcCfg.PanLevMdul.Lbl.21",
            "DcCfg.PanLevMdul.Lbl.22",
            "DcCfg.PanLevMdul.Lbl.23",
            "DcCfg.PanLevMdul.Lbl.24",
            "DcCfg.PanLevMdul.Lbl.25",
            "DcCfg.PanLevMdul.Lbl.26",
            "DcCfg.PanLevMdul.Lbl.27",
            "DcCfg.PanLevMdul.Lbl.28",
            "DcCfg.PanLevMdul.Lbl.29",
            "DcCfg.PanLevMdul.Lbl.30",
            "DcCfg.PanLevMdul.Lbl.31",
            "DcCfg.PanLevMdul.Lbl.32",
            "DcCfg.PanLevMdul.Lbl.33",
            "DcCfg.PanLevMdul.Lbl.34",
            "DcCfg.PanLevMdul.Lbl.35",
            "DcCfg.PanLevMdul.Lbl.36",
            "DcCfg.PanLevMdul.Lbl.37",
            "DcCfg.PanLevMdul.Lbl.38",
            "DcCfg.PanLevMdul.Lbl.39",
            "DcCfg.PanLevMdul.Lbl.40",
            "DcCfg.PanLevMdul.Lbl.41",
            "DcCfg.PanLevMdul.Lbl.42",
            "DcCfg.PanLevMdul.Lbl.43",
            "DcCfg.PanLevMdul.Lbl.44",
            "DcCfg.PanLevMdul.Lbl.45",
            "DcCfg.PanLevMdul.Lbl.46",
            "DcCfg.PanLevMdul.Lbl.47",
            "DcCfg.PanLevMdul.Lbl.48",
            "DcCfg.PanLevMdul.Lbl.49",
            "DcCfg.PanLevMdul.Lbl.50",
            "DcCfg.PanLevMdul.Lbl.51",
            "DcCfg.PanLevMdul.Lbl.52",
            "DcCfg.PanLevMdul.Lbl.53",
            "DcCfg.PanLevMdul.Lbl.54",
            "DcCfg.PanLevMdul.Lbl.55",
            "DcCfg.PanLevMdul.Lbl.56",
            "DcCfg.PanLevMdul.Lbl.57",
            "DcCfg.PanLevMdul.Lbl.58",
            "DcCfg.PanLevMdul.Lbl.59",
            "DcCfg.PanLevMdul.Lbl.60",
            "Inverter.OutPhs",
            "Inverter.WGraRecon",
            "SwCmp.CmpMainBlt.SwRev",
            "Nameplate.PkgRev",
            "GridGuard.Cntry.HzRtg",
            "GridGuard.Cntry.FrqCtl.lLimTmms",
            "Inverter.CtlComCfg.WCtlCom.TmsOut",
            "Inverter.PFMinQ1",
            "GridGuard.Cntry.FrqCtl.ChgMax",
            "Inverter.CtlComCfg.VArCtlVolCom.TmsOut",
            "IecCfg.GoCfg.GoAppId",
            "Inverter.VArModCfg.PFCfg.Dyn.WFilTms",
            "Nameplate.PkgUpdAval",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.DsaVolPu",
            "GridGuard.Cntry.FrqCtl.ReconMaxFrqMax",
            "GridGuard.Cntry.FrqCtl.ConnMax",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.EnaUnVolPu",
            "Inverter.CtlComCfg.WCtlCom2.FlbWMin",
            "Wl.SnetMsk",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCfg.Crv.XVal.4",
            "Metering.TotOpTmhSet",
            "GridGuard.Cntry.FrqCtl.hLim",
            "DcCfg.PanLevStrg.Lbl.1",
            "DcCfg.PanLevStrg.Lbl.2",
            "DcCfg.PanLevStrg.Lbl.3",
            "DcCfg.PanLevStrg.Lbl.4",
            "DcCfg.PanLevStrg.Lbl.5",
            "DcCfg.PanLevStrg.Lbl.6",
            "DcCfg.PanLevStrg.Lbl.7",
            "DcCfg.PanLevStrg.Lbl.8",
            "DcCfg.PanLevStrg.Lbl.9",
            "DcCfg.PanLevStrg.Lbl.10",
            "PCC.WMaxMod",
            "DtTm.SetDlSvTm",
            "GridGuard.CntryBas",
            "GridGuard.Cntry.GriStrTms",
            "Inverter.WModCfg.WCtlVolCfg.WTmEna",
            "Inverter.VArModCfg.VArModZerW",
            "Mb.ScdInEna",
            "GridGuard.Cntry.VolCtl.llLimPu",
            "Nameplate.ModelStr",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraPos",
            "Inverter.DGSModCfg.VArDynEna",
            "DcCfg.PanLevCtl.SerNum",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.ActTms",
            "Inverter.StopTms",
            "Nameplate.CmpCom.HwRev",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.EnaVolPu",
            "Spdwr.ActlGwIp",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.NumPt",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.NumPtMax",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArTms",
            "Inverter.VArModCfg.OutWNomLimDeAct",
            "GridGuard.Cntry.GriFltReConTms",
            "GridGuard.Cntry.VolCtl.MaxPeakTmms",
            "Inverter.WModCfg.WCtlVolCfg.WGraEna",
            "Inverter.VAMaxIn",
            "Spdwr.DnsSrvIp",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.1",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.2",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.3",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.4",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.5",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.6",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.7",
            "Inverter.WModCfg.WCtlVolCfg.Crv.XVal.8",
            "GridGuard.Cntry.VolCtl.hhLimTmms",
            "Inverter.VArMaxQ2Rtg",
            "Wl.Sec.Ssid",
            "GridGuard.Cntry.FrqCtl.SwMin",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.3",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.WNom.4",
            "GridGuard.Cntry.FrqCtl.ChgMaxTmms",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFIn",
            "Inverter.VArModCfg.OutWNomLimAct",
            "Inverter.VArModCfg.VArModOutFlb",
            "Card.DatLogUsr",
            "Nameplate.WlMacId",
            "DtTm.TmSynIsOn",
            "Inverter.WModCfg.WCtlVolCfg.WRefMod",
            "Nameplate.Vendor",
            "Nameplate.VendorStr",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArTmEna",
            "DcCfg.PanLevCom.SerNum.1",
            "DcCfg.PanLevCom.SerNum.2",
            "DcCfg.PanLevCom.SerNum.3",
            "DcCfg.PanLevCom.SerNum.4",
            "Wl.AutoCfgIsOn",
            "Metering.EnMtrTyp",
            "Wl.SoftAcsIsOn",
            "Inverter.VArModCfg.VArCnstCfgDmd.VAr",
            "Inverter.WCtlHzModCfg.HzFilTms",
            "GridGuard.Cntry.GriFltMonTms",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraPos",
            "Inverter.WModCfg.WCtlVolCfg.WTms",
            "Inverter.VArModCfg.PFCnstCfg.PFExtIn",
            "Inverter.DGSModCfg.ZerCurUnVolPu",
            "Operation.GrnLedWInd",
            "DcCfg.PanLevCom.Model.1",
            "DcCfg.PanLevCom.Model.2",
            "DcCfg.PanLevCom.Model.3",
            "DcCfg.PanLevCom.Model.4",
            "Inverter.CtlComCfg.WCtlCom.CtlComMssMod",
            "Inverter.VArMaxZerWQ4",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvStop",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzOvGra.3",
            "Inverter.PlntCtl.VRef",
            "Inverter.WGraMpp",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.ActTms",
            "Metering.MsSpdwr.UsSerNumEN.1",
            "Metering.MsSpdwr.UsSerNumEN.2",
            "Metering.MsSpdwr.UsSerNumEN.3",
            "Metering.MsSpdwr.UsSerNumEN.4",
            "Metering.MsSpdwr.UsSerNumEN.5",
            "Metering.MsSpdwr.UsSerNumEN.6",
            "Metering.MsSpdwr.UsSerNumEN.7",
            "Metering.MsSpdwr.UsSerNumEN.8",
            "Metering.MsSpdwr.UsSerNumEN.9",
            "Metering.MsSpdwr.UsSerNumEN.10",
            "DcCfg.PanLevMdul.HwRev.1",
            "DcCfg.PanLevMdul.HwRev.2",
            "DcCfg.PanLevMdul.HwRev.3",
            "DcCfg.PanLevMdul.HwRev.4",
            "DcCfg.PanLevMdul.HwRev.5",
            "DcCfg.PanLevMdul.HwRev.6",
            "DcCfg.PanLevMdul.HwRev.7",
            "DcCfg.PanLevMdul.HwRev.8",
            "DcCfg.PanLevMdul.HwRev.9",
            "DcCfg.PanLevMdul.HwRev.10",
            "DcCfg.PanLevMdul.HwRev.11",
            "DcCfg.PanLevMdul.HwRev.12",
            "DcCfg.PanLevMdul.HwRev.13",
            "DcCfg.PanLevMdul.HwRev.14",
            "DcCfg.PanLevMdul.HwRev.15",
            "DcCfg.PanLevMdul.HwRev.16",
            "DcCfg.PanLevMdul.HwRev.17",
            "DcCfg.PanLevMdul.HwRev.18",
            "DcCfg.PanLevMdul.HwRev.19",
            "DcCfg.PanLevMdul.HwRev.20",
            "DcCfg.PanLevMdul.HwRev.21",
            "DcCfg.PanLevMdul.HwRev.22",
            "DcCfg.PanLevMdul.HwRev.23",
            "DcCfg.PanLevMdul.HwRev.24",
            "DcCfg.PanLevMdul.HwRev.25",
            "DcCfg.PanLevMdul.HwRev.26",
            "DcCfg.PanLevMdul.HwRev.27",
            "DcCfg.PanLevMdul.HwRev.28",
            "DcCfg.PanLevMdul.HwRev.29",
            "DcCfg.PanLevMdul.HwRev.30",
            "DcCfg.PanLevMdul.HwRev.31",
            "DcCfg.PanLevMdul.HwRev.32",
            "DcCfg.PanLevMdul.HwRev.33",
            "DcCfg.PanLevMdul.HwRev.34",
            "DcCfg.PanLevMdul.HwRev.35",
            "DcCfg.PanLevMdul.HwRev.36",
            "DcCfg.PanLevMdul.HwRev.37",
            "DcCfg.PanLevMdul.HwRev.38",
            "DcCfg.PanLevMdul.HwRev.39",
            "DcCfg.PanLevMdul.HwRev.40",
            "DcCfg.PanLevMdul.HwRev.41",
            "DcCfg.PanLevMdul.HwRev.42",
            "DcCfg.PanLevMdul.HwRev.43",
            "DcCfg.PanLevMdul.HwRev.44",
            "DcCfg.PanLevMdul.HwRev.45",
            "DcCfg.PanLevMdul.HwRev.46",
            "DcCfg.PanLevMdul.HwRev.47",
            "DcCfg.PanLevMdul.HwRev.48",
            "DcCfg.PanLevMdul.HwRev.49",
            "DcCfg.PanLevMdul.HwRev.50",
            "DcCfg.PanLevMdul.HwRev.51",
            "DcCfg.PanLevMdul.HwRev.52",
            "DcCfg.PanLevMdul.HwRev.53",
            "DcCfg.PanLevMdul.HwRev.54",
            "DcCfg.PanLevMdul.HwRev.55",
            "DcCfg.PanLevMdul.HwRev.56",
            "DcCfg.PanLevMdul.HwRev.57",
            "DcCfg.PanLevMdul.HwRev.58",
            "DcCfg.PanLevMdul.HwRev.59",
            "DcCfg.PanLevMdul.HwRev.60",
            "Inverter.VArModCfg.VRefMod",
            "DcCfg.PanLevCtl.PlntId",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.4",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.5",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.6",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.7",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.YVal.8",
            "Spdwr.SnetMsk",
            "Metering.MsSpdwr.MsCyc",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.WFilTms",
            "DcCfg.MPPShdw.IsOn",
            "Inverter.WModCfg.WCtlVolCfg.VRefMod",
            "Metering.GridMs.TotkWhInOfs",
            "GridGuard.Cntry.FrqCtl.hLimTmms",
            "Inverter.VArModCfg.VArCfg.Crv.CrvEna",
            "Eth.Proxy.Login",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.WFilTmEna",
            "Nameplate.Model",
            "Inverter.WLim",
            "GridGuard.Cntry.VolCtl.MinTmms",
            "Metering.Mb.SwRev",
            "GridGuard.Cntry.AMaxOfsTmms",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraNeg",
            "Inverter.VArModCfg.VArCnstCfgDmd.VArNom",
            "Inverter.CtlComCfg.VArCtlCom.FlbVArNom",
            "Nameplate.CmpMain.SusyId",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraNeg",
            "Inverter.CtlComCfg.WCtlCom2.FlbWMax",
            "GridGuard.Cntry.Aid.HzMon.Stt",
            "Inverter.VAMaxOut",
            "GridGuard.Cntry.VolCtl.lLimTmms",
            "Inverter.VArModCfg.VArCtlWCfg.Trg.EnaUnVolPu",
            "WebConn.SwRev",
            "Inverter.VArModCfg.PFCnstCfg.PFExtOut",
            "DcCfg.PanLevMdul.SwRev.1",
            "DcCfg.PanLevMdul.SwRev.2",
            "DcCfg.PanLevMdul.SwRev.3",
            "DcCfg.PanLevMdul.SwRev.4",
            "DcCfg.PanLevMdul.SwRev.5",
            "DcCfg.PanLevMdul.SwRev.6",
            "DcCfg.PanLevMdul.SwRev.7",
            "DcCfg.PanLevMdul.SwRev.8",
            "DcCfg.PanLevMdul.SwRev.9",
            "DcCfg.PanLevMdul.SwRev.10",
            "DcCfg.PanLevMdul.SwRev.11",
            "DcCfg.PanLevMdul.SwRev.12",
            "DcCfg.PanLevMdul.SwRev.13",
            "DcCfg.PanLevMdul.SwRev.14",
            "DcCfg.PanLevMdul.SwRev.15",
            "DcCfg.PanLevMdul.SwRev.16",
            "DcCfg.PanLevMdul.SwRev.17",
            "DcCfg.PanLevMdul.SwRev.18",
            "DcCfg.PanLevMdul.SwRev.19",
            "DcCfg.PanLevMdul.SwRev.20",
            "DcCfg.PanLevMdul.SwRev.21",
            "DcCfg.PanLevMdul.SwRev.22",
            "DcCfg.PanLevMdul.SwRev.23",
            "DcCfg.PanLevMdul.SwRev.24",
            "DcCfg.PanLevMdul.SwRev.25",
            "DcCfg.PanLevMdul.SwRev.26",
            "DcCfg.PanLevMdul.SwRev.27",
            "DcCfg.PanLevMdul.SwRev.28",
            "DcCfg.PanLevMdul.SwRev.29",
            "DcCfg.PanLevMdul.SwRev.30",
            "DcCfg.PanLevMdul.SwRev.31",
            "DcCfg.PanLevMdul.SwRev.32",
            "DcCfg.PanLevMdul.SwRev.33",
            "DcCfg.PanLevMdul.SwRev.34",
            "DcCfg.PanLevMdul.SwRev.35",
            "DcCfg.PanLevMdul.SwRev.36",
            "DcCfg.PanLevMdul.SwRev.37",
            "DcCfg.PanLevMdul.SwRev.38",
            "DcCfg.PanLevMdul.SwRev.39",
            "DcCfg.PanLevMdul.SwRev.40",
            "DcCfg.PanLevMdul.SwRev.41",
            "DcCfg.PanLevMdul.SwRev.42",
            "DcCfg.PanLevMdul.SwRev.43",
            "DcCfg.PanLevMdul.SwRev.44",
            "DcCfg.PanLevMdul.SwRev.45",
            "DcCfg.PanLevMdul.SwRev.46",
            "DcCfg.PanLevMdul.SwRev.47",
            "DcCfg.PanLevMdul.SwRev.48",
            "DcCfg.PanLevMdul.SwRev.49",
            "DcCfg.PanLevMdul.SwRev.50",
            "DcCfg.PanLevMdul.SwRev.51",
            "DcCfg.PanLevMdul.SwRev.52",
            "DcCfg.PanLevMdul.SwRev.53",
            "DcCfg.PanLevMdul.SwRev.54",
            "DcCfg.PanLevMdul.SwRev.55",
            "DcCfg.PanLevMdul.SwRev.56",
            "DcCfg.PanLevMdul.SwRev.57",
            "DcCfg.PanLevMdul.SwRev.58",
            "DcCfg.PanLevMdul.SwRev.59",
            "DcCfg.PanLevMdul.SwRev.60",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.VolPu.4",
            "Eth.Proxy.Port",
            "DcCfg.MPPShdw.CycTms",
            "Inverter.VArModCfg.PFCfg.Dyn.VArTms",
            "Inverter.WModCfg.WCtlVolCfg.Crv.NumPt",
            "Inverter.VArModCfg.VArModIn",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WTmEna",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArTmEna",
            "Eth.Proxy.Pwd",
            "Mb.UdpSrv.Port",
            "Inverter.VAMaxOutRtg",
            "Inverter.FltAMod",
            "Inverter.WGraMppEna",
            "Inverter.WModCfg.WCtlVolCfg.Ena",
            "DtTm.DlSvIsOn",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArGraPos",
            "Inverter.WModCfg.WCtlComCfg2.LoPrioEna",
            "GridGuard.Cntry.FrqCtl.ConnMin",
            "Wl.ActlIp",
            "DcCfg.PanLevCom.SwRev.1",
            "DcCfg.PanLevCom.SwRev.2",
            "DcCfg.PanLevCom.SwRev.3",
            "DcCfg.PanLevCom.SwRev.4",
            "Inverter.VArModCfg.ImpCpn.IsOn",
            "Inverter.VArMaxZerWQ1",
            "Inverter.CtlComCfg.PFCtlCom.CtlComMssMod",
            "Acs.PwdUsr",
            "Inverter.PlntCtl.VRefMod",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.NumPt",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HystEnaOv",
            "DcCfg.PanLevCom.HwRev.1",
            "DcCfg.PanLevCom.HwRev.2",
            "DcCfg.PanLevCom.HwRev.3",
            "DcCfg.PanLevCom.HwRev.4",
            "GridGuard.Cntry.AMaxOfsMod",
            "GridGuard.Cntry.VolCtl.llLimTmms",
            "Nameplate.CmpMain.SerNum",
            "Nameplate.CmpOS.SwRev",
            "Inverter.WModCfg.WCtlComCfg.Dyn.WGraPos",
            "WebConn.IsOn",
            "DcCfg.PanLevStrg.MdulCnt.1",
            "DcCfg.PanLevStrg.MdulCnt.2",
            "DcCfg.PanLevStrg.MdulCnt.3",
            "DcCfg.PanLevStrg.MdulCnt.4",
            "DcCfg.PanLevStrg.MdulCnt.5",
            "DcCfg.PanLevStrg.MdulCnt.6",
            "DcCfg.PanLevStrg.MdulCnt.7",
            "DcCfg.PanLevStrg.MdulCnt.8",
            "DcCfg.PanLevStrg.MdulCnt.9",
            "DcCfg.PanLevStrg.MdulCnt.10",
            "Inverter.VArMaxZerWQ2",
            "GridGuard.Cntry.FrqCtl.MaxTmms",
            "Mb.UdpSrv.IsOn",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCfg.Crv.YVal.4",
            "Inverter.CtlComCfg.WCtlCom2.CtlComMssMod",
            "Inverter.VArMaxQ4Rtg",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArTms",
            "DcCfg.PanLevCom.GwCnt",
            "Inverter.WMax",
            "Inverter.VArMaxZerWQ3",
            "Inverter.VArModCfg.HystTms",
            "GridGuard.Cntry.VolCtl.MaxPuTmms",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArTmEna",
            "DcCfg.ConstVolCtl.Vset.1",
            "DcCfg.ConstVolCtl.Vset.2",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFExt",
            "DcCfg.PanLevStrg.MPPTrk.1",
            "DcCfg.PanLevStrg.MPPTrk.2",
            "DcCfg.PanLevStrg.MPPTrk.3",
            "DcCfg.PanLevStrg.MPPTrk.4",
            "DcCfg.PanLevStrg.MPPTrk.5",
            "DcCfg.PanLevStrg.MPPTrk.6",
            "DcCfg.PanLevStrg.MPPTrk.7",
            "DcCfg.PanLevStrg.MPPTrk.8",
            "DcCfg.PanLevStrg.MPPTrk.9",
            "DcCfg.PanLevStrg.MPPTrk.10",
            "Inverter.VArModCfg.PFCtlWCfg.Trg.DsaUnVolPu",
            "GridGuard.Cntry.FrqCtl.MinTmms",
            "Inverter.VArModCfg.VArModZerWFlb",
            "SwCmp.CmpWebUsrItf.SwRev",
            "Inverter.VArModCfg.VArCnstCfgIn.VArNom",
            "Wl.Sec.Cry",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraNeg",
            "Spdwr.Ip",
            "Inverter.DGSModCfg.DGSMod",
            "Inverter.DGSModCfg.AvLtTms",
            "PCC.WMaxNom",
            "Metering.TotFeedTmhSet",
            "Nameplate.CmpMain.HwVer",
            "GridGuard.Cntry.VolCtl.ConnMinPu",
            "Inverter.VAMaxInRtg",
            "Inverter.VArMaxQ1",
            "Mb.SunSpec.MdbPrflRev",
            "GridGuard.Cntry.FrqCtl.SwMinTmms",
            "GridGuard.Cntry.Aid.HzMon.HzMonTmms",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HystEnaUn",
            "Inverter.ASTTypeRO",
            "DcCfg.StrTms.1",
            "DcCfg.StrTms.2",
            "Inverter.VArModCfg.VArCtlVolCfg.Dyn.VArTmEna",
            "PCC.WMax",
            "GridGuard.Cntry.VolCtl.hLimPu",
            "Inverter.VArModCfg.VArCfg.Dyn.VArTmEna",
            "Inverter.PFMinQ2Rtg",
            "Spdwr.GwIp",
            "Coolsys.FanTst",
            "Inverter.VArMaxQ2",
            "GridGuard.Cntry.VolCtl.MinPu",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.NumPtMax",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WTms",
            "Inverter.VArGraConnEna",
            "Inverter.CtlComCfg.PFCtlCom.FlbPFExtIn",
            "Inverter.VArModCfg.VArCtlWCfg.Dyn.VArTms",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraPos",
            "Inverter.WModCfg.WCnstCfg.WNom",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.VArGraPos",
            "Inverter.VArModCfg.VArModOut",
            "Inverter.WCtlHzModCfg.RefModUn",
            "Spdwr.ActlDnsSrvIp",
            "Inverter.VArModCfg.VArCtlVolCfg.VolRef.AutnAdjMod",
            "Inverter.DGSModCfg.VRefThMod",
            "Wl.ActlGwIp",
            "PCC.FlbInv.WMax",
            "Inverter.WCtlHzModCfg.WTms",
            "RS485.RS485Mod",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.1",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.2",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.3",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.4",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.5",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.6",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.7",
            "Inverter.VArModCfg.VArCtlVolCfg.Crv.XVal.8",
            "Inverter.CtlComCfg.VArCtlVolCom.CtlComMssMod",
            "Inverter.WMaxInRtg",
            "GridGuard.Cntry.VolCtl.MaxPu",
            "Mb.TcpSrv.IsOn",
            "Inverter.VArModCfg.VArCnstCfg.VArNom",
            "GridGuard.Cntry",
            "GridGuard.Cntry.AMaxOfs",
            "GridGuard.Cntry.LeakRisMin",
            "DcCfg.PanLevCtl.Model",
            "GridGuard.Cntry.GriFltTms",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WTmEna",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.1",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.2",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.3",
            "Inverter.VArModCfg.PFCtlWCfg.Crv.PF.4",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.NumPt",
            "Inverter.VArModCfg.PFCtlVolCfg.Dyn.VArGraNeg",
            "Inverter.WGraConn",
            "GridGuard.Cntry.FrqCtl.Max",
            "Wl.Ip",
            "SwCmp.CmpTmZn.SwRev",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PFExt.4",
            "DcCfg.PanLevMdul.Model.1",
            "DcCfg.PanLevMdul.Model.2",
            "DcCfg.PanLevMdul.Model.3",
            "DcCfg.PanLevMdul.Model.4",
            "DcCfg.PanLevMdul.Model.5",
            "DcCfg.PanLevMdul.Model.6",
            "DcCfg.PanLevMdul.Model.7",
            "DcCfg.PanLevMdul.Model.8",
            "DcCfg.PanLevMdul.Model.9",
            "DcCfg.PanLevMdul.Model.10",
            "DcCfg.PanLevMdul.Model.11",
            "DcCfg.PanLevMdul.Model.12",
            "DcCfg.PanLevMdul.Model.13",
            "DcCfg.PanLevMdul.Model.14",
            "DcCfg.PanLevMdul.Model.15",
            "DcCfg.PanLevMdul.Model.16",
            "DcCfg.PanLevMdul.Model.17",
            "DcCfg.PanLevMdul.Model.18",
            "DcCfg.PanLevMdul.Model.19",
            "DcCfg.PanLevMdul.Model.20",
            "DcCfg.PanLevMdul.Model.21",
            "DcCfg.PanLevMdul.Model.22",
            "DcCfg.PanLevMdul.Model.23",
            "DcCfg.PanLevMdul.Model.24",
            "DcCfg.PanLevMdul.Model.25",
            "DcCfg.PanLevMdul.Model.26",
            "DcCfg.PanLevMdul.Model.27",
            "DcCfg.PanLevMdul.Model.28",
            "DcCfg.PanLevMdul.Model.29",
            "DcCfg.PanLevMdul.Model.30",
            "DcCfg.PanLevMdul.Model.31",
            "DcCfg.PanLevMdul.Model.32",
            "DcCfg.PanLevMdul.Model.33",
            "DcCfg.PanLevMdul.Model.34",
            "DcCfg.PanLevMdul.Model.35",
            "DcCfg.PanLevMdul.Model.36",
            "DcCfg.PanLevMdul.Model.37",
            "DcCfg.PanLevMdul.Model.38",
            "DcCfg.PanLevMdul.Model.39",
            "DcCfg.PanLevMdul.Model.40",
            "DcCfg.PanLevMdul.Model.41",
            "DcCfg.PanLevMdul.Model.42",
            "DcCfg.PanLevMdul.Model.43",
            "DcCfg.PanLevMdul.Model.44",
            "DcCfg.PanLevMdul.Model.45",
            "DcCfg.PanLevMdul.Model.46",
            "DcCfg.PanLevMdul.Model.47",
            "DcCfg.PanLevMdul.Model.48",
            "DcCfg.PanLevMdul.Model.49",
            "DcCfg.PanLevMdul.Model.50",
            "DcCfg.PanLevMdul.Model.51",
            "DcCfg.PanLevMdul.Model.52",
            "DcCfg.PanLevMdul.Model.53",
            "DcCfg.PanLevMdul.Model.54",
            "DcCfg.PanLevMdul.Model.55",
            "DcCfg.PanLevMdul.Model.56",
            "DcCfg.PanLevMdul.Model.57",
            "DcCfg.PanLevMdul.Model.58",
            "DcCfg.PanLevMdul.Model.59",
            "DcCfg.PanLevMdul.Model.60",
            "Nameplate.CmpCom.SwRev",
            "Inverter.VArModCfg.PFCfg.Dyn.VArGraEna",
            "Metering.GridMs.TotkWhOutOfs",
            "Inverter.PFMinQ1Rtg",
            "GridGuard.Cntry.FrqCtl.ReconMin",
            "Sys.SelfTstDmd",
            "Inverter.VArModCfg.PFCfg.Dyn.VArTmEna",
            "Inverter.WCtlHzModCfg.Ena",
            "Inverter.VArModCfg.PFMinEna",
            "Inverter.VArModCfg.VArCfg.Dyn.VArGraEna",
            "Spdwr.IgmpQryTx",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.WFilTms",
            "PvGen.PvWhSet",
            "Inverter.VArModCfg.ImpCpn.OhmRis",
            "Inverter.WModCfg.WCtlVolCfg.WGraPos",
            "DcCfg.PanLevStrg.OptCnt.1",
            "DcCfg.PanLevStrg.OptCnt.2",
            "DcCfg.PanLevStrg.OptCnt.3",
            "DcCfg.PanLevStrg.OptCnt.4",
            "DcCfg.PanLevStrg.OptCnt.5",
            "DcCfg.PanLevStrg.OptCnt.6",
            "DcCfg.PanLevStrg.OptCnt.7",
            "DcCfg.PanLevStrg.OptCnt.8",
            "DcCfg.PanLevStrg.OptCnt.9",
            "DcCfg.PanLevStrg.OptCnt.10",
            "Inverter.CtlComCfg.WCtlCom.FlbWMax",
            "Metering.Mb.EnMtrSerNumTxt",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.1",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.2",
            "Inverter.WCtlHzModCfg.WCtlHzCfg.HzUn.3",
            "Inverter.CtlComCfg.WCtlCom2.TmsOut",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.1",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.2",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.3",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.4",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.5",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.6",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.7",
            "Inverter.VArModCfg.VArCtlWCfg.Crv.YVal.8",
            "Sys.EthDiag",
            "GridGuard.Cntry.VRtg",
            "Inverter.DGSModCfg.HystVolPu",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.1",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.2",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.3",
            "Inverter.VArModCfg.PFCtlVolCfg.Crv.PF.4",
            "GridGuard.Cntry.FrqCtl.lLim",
            "IecCfg.GoCfg.GoMacId",
            "Inverter.VArMaxQ3",
            "Wl.IsOn",
            "Inverter.VArModCfg.PFCtlWCfg.Dyn.WFilTmEna",
            "Wl.ExsNetw.1",
            "Wl.ExsNetw.2",
            "Wl.ExsNetw.3",
            "Inverter.WModCfg.WCtlVolCfg.WGraNeg",
            "Eth.Proxy.Srv",
            "Inverter.WModCfg.WCtlComCfg2.Dyn.WGraEna",
            "Mb.TcpSrv.Port",
            "Wl.GwIp",
            "Inverter.VArMaxQ4",
        ],
    ),
]

# fmt: off
# black -C -l 200 pysma/definitions_ennexos.py
enneoxSensors = [
        Sensor("Bat.Amp.1", Identifier.battery_current_a, factor=1, unit='A'),
        Sensor("Bat.ChaStt", Identifier.battery_soc_total, factor=1, unit='%'),
        Sensor("Bat.ChaSttArr.1", Identifier.battery_soc_a, factor=1, unit='%'),
        Sensor("Bat.TmpVal.1", Identifier.battery_temp_a, factor=1, unit="°C"),
        Sensor("BatChrg.BatChrgArr.1", None, factor=1, unit=None),
        Sensor("BatChrg.BatChrg", None, factor=1, unit=None),
        Sensor("BatChrg.CurBatCha", Identifier.battery_power_charge_total, factor=1, unit="W"),
        Sensor("BatChrg.CurBatChaArr.1", Identifier.battery_power_charge_a, factor=1, unit="W"),
        Sensor("Bat.Diag.VolMax.1", None, factor=1, unit=None),
        Sensor("BatDsch.BatDschArr.1", None, factor=1, unit=None),
        Sensor("BatDsch.BatDsch", None, factor=1, unit=None),
        Sensor("BatDsch.CurBatDsch", Identifier.battery_power_discharge_total, factor=1, unit="W"),
        Sensor("BatDsch.CurBatDschArr.1", Identifier.battery_power_discharge_a, factor=1, unit="W"),
        Sensor("Bat.OpTms.1", None, factor=1, unit=None),
        Sensor("Bat.Vol.1", Identifier.battery_voltage_a, factor=1, unit="V"),
        Sensor("ChaSess.WhIn", None, factor=1, unit=None),
        Sensor("Chrg.ModSw", None, factor=1, unit=None, mapper=SMATagList),
        Sensor("Coolsys.Inverter.TmpVal.1", Identifier.temp_a, factor=1, unit="°C"),
        Sensor("Coolsys.Inverter.TmpVal.2", Identifier.temp_b, factor=1, unit="°C"),
        Sensor("Coolsys.Inverter.TmpVal.3", Identifier.temp_c, factor=1, unit="°C"),
        Sensor("DcMs.Amp.1", Identifier.pv_current_a, factor=1, unit="A"),
        Sensor("DcMs.Amp.2", Identifier.pv_current_b, factor=1, unit="A"),
        Sensor("DcMs.Amp.3", Identifier.pv_current_c, factor=1, unit="A"),
        Sensor("DcMs.TotDcEnCntWh.1", Identifier.pv_total_power_a, factor=1000, unit="kWh"),
        Sensor("DcMs.TotDcEnCntWh.2", Identifier.pv_total_power_b, factor=1000, unit="kWh"),
        Sensor("DcMs.TotDcEnCntWh.3", Identifier.pv_total_power_c, factor=1000, unit="kWh"),
        Sensor("DcMs.Vol.1", Identifier.pv_voltage_a, factor=1, unit="V"),
        Sensor("DcMs.Vol.2", Identifier.pv_voltage_b, factor=1, unit="V"),
        Sensor("DcMs.Vol.3", Identifier.pv_voltage_c, factor=1, unit="V"),
        Sensor("DcMs.Watt.1", Identifier.pv_power_a, factor=1, unit="W"),
        Sensor("DcMs.Watt.2", Identifier.pv_power_b, factor=1, unit="W"),
        Sensor("DcMs.Watt.3", Identifier.pv_power_c, factor=1, unit="W"),
        Sensor("DevUpd.IsOn", None, factor=1, unit=None),
        Sensor("EpsMs.Amp", None, factor=1, unit=None),
        Sensor("EpsMs.Vol", None, factor=1, unit=None),
        Sensor("EpsMs.Watt", None, factor=1, unit=None),
        Sensor("FTPPush.IsOn", None, factor=1, unit=None),
        Sensor("FTPPush.Login", None, factor=1, unit=None),
        Sensor("FTPPush.Port", None, factor=1, unit=None),
        Sensor("FTPPush.Pwd", None, factor=1, unit=None),
        Sensor("FTPPush.RemStoLcn", None, factor=1, unit=None),
        Sensor("FTPPush.Srv", None, factor=1, unit=None),
        Sensor("FTPPush.UpldCyc", None, factor=1, unit=None),
        Sensor("GridGuard.Cntry", None, factor=1, unit=None),
        Sensor("GridMs.A.phsA", Identifier.current_l1, factor=1, unit="A"),
        Sensor("GridMs.A.phsB", Identifier.current_l2, factor=1, unit="A"),
        Sensor("GridMs.A.phsC", Identifier.current_l3, factor=1, unit="A"),
        Sensor("GridMs.GriTyp", None, factor=1, unit=None),
        Sensor("GridMs.Hz", Identifier.frequency, factor=1, unit="Hz"),
        Sensor("GridMs.PhV.phsA2B", None, factor=1, unit=None),
        Sensor("GridMs.PhV.phsA", Identifier.voltage_l1, factor=1, unit="V"),
        Sensor("GridMs.PhV.phsB2C", None, factor=1, unit=None),
        Sensor("GridMs.PhV.phsB", Identifier.voltage_l2, factor=1, unit="V"),
        Sensor("GridMs.PhV.phsC2A", None, factor=1, unit=None),
        Sensor("GridMs.PhV.phsC", Identifier.voltage_l3, factor=1, unit="V"),
        Sensor("GridMs.TotA", Identifier.current_total, factor=1, unit="A"),
        Sensor("GridMs.TotPFEEI", None, factor=1, unit=None),
        Sensor("GridMs.TotPFExt", None, factor=1, unit=None),
        Sensor("GridMs.TotPF", None, factor=1, unit=None),
        Sensor("GridMs.TotPFPrc", None, factor=1, unit=None),
        Sensor("GridMs.TotVA", Identifier.grid_apparent_power, factor=1, unit="VA"),
        Sensor("GridMs.TotVAr", Identifier.grid_reactive_power, factor=1, unit="var"),
        Sensor("GridMs.TotW", Identifier.grid_power, factor=1, unit="W"),
        Sensor("GridMs.TotW.Pv", Identifier.pv_power, factor=1, unit="W"),
        Sensor("GridMs.VA.phsA", Identifier.grid_apparent_power_l1, factor=1, unit="VA"),
        Sensor("GridMs.VA.phsB", Identifier.grid_apparent_power_l2, factor=1, unit="VA"),
        Sensor("GridMs.VA.phsC", Identifier.grid_apparent_power_l3, factor=1, unit="VA"),
        Sensor("GridMs.VAr.phsA", Identifier.grid_reactive_power_l1, factor=1, unit="var"),
        Sensor("GridMs.VAr.phsB", Identifier.grid_reactive_power_l2, factor=1, unit="var"),
        Sensor("GridMs.VAr.phsC", Identifier.grid_reactive_power_l3, factor=1, unit="var"),
        Sensor("GridMs.W.phsA", Identifier.power_l1, factor=1, unit="W"),
        Sensor("GridMs.W.phsB", Identifier.power_l2, factor=1, unit="W"),
        Sensor("GridMs.W.phsC", Identifier.power_l3, factor=1, unit="W"),
        Sensor("InOut.GI1", None, factor=1, unit=None),  # codespell:ignore
        Sensor("InOut.GO1", None, factor=1, unit=None),  # codespell:ignore
        Sensor("Inverter.VArModCfg.PFCtlVolCfg.Stt", None, factor=1, unit=None),
        Sensor("Inverter.WMax", Identifier.inverter_power_limit, factor=1, unit="W"),
        Sensor("Isolation.FltA", Identifier.insulation_residual_current, factor=1000, unit="mA"),
        Sensor("Isolation.LeakRis", None, factor=1, unit="kOhm"),
        Sensor("Isolation.LeakRis", None, factor=1, unit=None),
        Sensor("Metering.GridMs.A.phsA", Identifier.current_l1, factor=1, unit="A"),
        Sensor("Metering.GridMs.A.phsB", Identifier.current_l2, factor=1, unit="A"),
        Sensor("Metering.GridMs.A.phsC", Identifier.current_l3, factor=1, unit="A"),
        Sensor("Metering.GridMs.Hz", Identifier.frequency, factor=1, unit="Hz"),
        Sensor("Metering.GridMs.PhV.phsA", Identifier.voltage_l1, factor=1, unit="V"),
        Sensor("Metering.GridMs.PhV.phsB", Identifier.voltage_l2, factor=1, unit="V"),
        Sensor("Metering.GridMs.PhV.phsC", Identifier.voltage_l3, factor=1, unit="V"),
        Sensor("Metering.GridMs.TotPF", None, factor=1, unit=None),
        Sensor("Metering.GridMs.TotWhIn.Bat", Identifier.battery_charge_total, factor=1000, unit="kWh"),
        Sensor("Metering.GridMs.TotWhIn.ChaSta", Identifier.charging_station_total_absorbed, factor=1000, unit="kWh"),
        Sensor("Metering.GridMs.TotWhIn", Identifier.metering_total_absorbed, factor=1000, unit="kWh"),
        # Sensor("Metering.GridMs.TotWhIn", Identifier.metering_total_yield, factor=1000, unit="kWh"),
        Sensor("Metering.GridMs.TotWhOut.Bat", Identifier.battery_discharge_total, factor=1000, unit="kWh"),
        Sensor("Metering.GridMs.TotWhOut", Identifier.metering_total_consumption, factor=1000, unit="kWh"),
        Sensor("Metering.GridMs.TotWIn.ChaSta", Identifier.charging_station_power_absorbed, factor=1, unit="W"),
        Sensor("Metering.GridMs.TotWIn", Identifier.metering_power_absorbed, factor=1, unit="W"),
        Sensor("Metering.GridMs.TotWOut", Identifier.metering_power_supplied, factor=1, unit="W"),
        Sensor("Metering.GridMs.VA.phsA", Identifier.grid_apparent_power_l1, factor=1, unit="VA"),
        Sensor("Metering.GridMs.VA.phsB", Identifier.grid_apparent_power_l2, factor=1, unit="VA"),
        Sensor("Metering.GridMs.VA.phsC", Identifier.grid_apparent_power_l3, factor=1, unit="VA"),
        Sensor("Metering.GridMs.VAr.phsA", Identifier.grid_reactive_power_l1, factor=1, unit="var"),
        Sensor("Metering.GridMs.VAr.phsB", Identifier.grid_reactive_power_l2, factor=1, unit="var"),
        Sensor("Metering.GridMs.VAr.phsC", Identifier.grid_reactive_power_l3, factor=1, unit="var"),
        Sensor("Metering.GridMs.W.phsA", Identifier.power_l1, factor=1, unit="W"),
        Sensor("Metering.GridMs.W.phsB", Identifier.power_l2, factor=1, unit="W"),
        Sensor("Metering.GridMs.W.phsC", Identifier.power_l3, factor=1, unit="W"),
        Sensor("Metering.TotFeedTms", None),
        Sensor("Metering.TotFeedTms", None, factor=1, unit=None),
        Sensor("Metering.TotOpTms", None),
        Sensor("Metering.TotOpTms", None, factor=1, unit=None),
        Sensor("Metering.TotWhIn", None, factor=1, unit=None),
        Sensor("Metering.TotWhOut", Identifier.total_yield, factor=1000, unit="kWh"),
        Sensor("Metering.TotWhOut.Pv", Identifier.pv_gen_meter, factor=1000, unit="kWh"),
        Sensor("Nameplate.CmpMain.HwRev", None, factor=1, unit=None),
        Sensor("Nameplate.CmpMain.Rev", None, factor=1, unit=None),
        Sensor("Nameplate.CmpOS.SwRev", None, factor=1, unit=None),
        Sensor("Nameplate.Location", None, factor=1, unit=None),
        Sensor("Nameplate.MainModel", None, factor=1, unit=None),
        Sensor("Nameplate.Model", None, factor=1, unit=None),
        Sensor("Nameplate.ModelStr", None, factor=1, unit=None),
        Sensor("Nameplate.PkgRev", None, factor=1, unit=None),
        Sensor("Nameplate.SerNum", None, factor=1, unit=None),
        Sensor("Nameplate.Vendor", None, factor=1, unit=None),
        Sensor("Operation.Bat.Health", None, factor=1, unit=None),
        Sensor("Operation.BckStt", None, factor=1, unit=None),
        Sensor("Operation.DrtStt", None, factor=1, unit=None),
        Sensor("Operation.EVeh.ChaStt", Identifier.operating_status, factor=1, unit=None, mapper=SMATagList),
        Sensor("Operation.EVeh.Health", Identifier.status, factor=1, unit=None, mapper=SMATagList),
        Sensor("Operation.EvtCntIstl", None, factor=1, unit=None),
        Sensor("Operation.EvtCntUsr", None, factor=1, unit=None),
        Sensor("Operation.Evt.Dsc", None, factor=1, unit=None),
        Sensor("Operation.Evt.EvtNo", None, factor=1, unit=None),
        Sensor("Operation.Evt.Msg", None, factor=1, unit=None),
        Sensor("Operation.GriSwCnt", None, factor=1, unit=None),
        Sensor("Operation.GriSwStt", Identifier.grid_relay_status, unit=None, mapper=SMATagList),
        Sensor("Operation.Health", Identifier.status, factor=1, unit=None, mapper=SMATagList),
        Sensor("Operation.HealthStt.Alm", None, factor=1, unit=None),
        Sensor("Operation.HealthStt.Ok", None, factor=1, unit=None),
        Sensor("Operation.HealthStt.Wrn", None, factor=1, unit=None),
        Sensor("Operation.OpStt", Identifier.operating_status_genereal, unit=None, mapper=SMATagList),
        Sensor("Operation.PvGriConn", None, factor=1, unit=None),
        Sensor("Operation.RstrLokStt", None, factor=1, unit=None),
        Sensor("Operation.RunStt", None, factor=1, unit=None),
        Sensor("Operation.StandbyStt", None, factor=1, unit=None),
        Sensor("Operation.VArCtl.VArModAct", None, factor=1, unit=None),
        Sensor("Operation.VArCtl.VArModStt", None, factor=1, unit=None),
        Sensor("Operation.WMaxLimNom", None, factor=1, unit=None),
        Sensor("Operation.WMaxLimSrc", None, factor=1, unit=None),
        Sensor("Operation.WMinLimSrc", None, factor=1, unit=None),
        Sensor("Portal.EnnexOS.ConnStt", None, factor=1, unit=None),
        Sensor("PvGen.PvWh", None, factor=1, unit=None),
        Sensor("PvGen.PvW", None, factor=1, unit=None),
        Sensor("Setpoint.PlantControl.CmpBMS.OpMod.1", None, factor=1, unit=None),
        Sensor("Setpoint.PlantControl.InOut.GO1", None, factor=1, unit=None),  # codespell:ignore
        Sensor("Spdwr.ActlDnsSrvIp", None, factor=1, unit=None),
        Sensor("Spdwr.ActlGwIp", None, factor=1, unit=None),
        Sensor("Spdwr.ActlIp", None, factor=1, unit=None),
        Sensor("Spdwr.ActlSnetMsk", None, factor=1, unit=None),
        Sensor("Spdwr.AutoCfgIsOn", None, factor=1, unit=None),
        Sensor("Spdwr.ComSocA.Stt", None, factor=1, unit=None),
        Sensor("Spdwr.IgmpQryTms", None, factor=1, unit=None),
        Sensor("Spdwr.IgmpQryTx", None, factor=1, unit=None),
        Sensor("SunSpecSig.SunSpecTx.1", None, factor=1, unit=None),
        Sensor("SwCmp.CmpEnnexOS.Frwk.SwRev", None, factor=1, unit=None),
        Sensor("Sys.DevRstr", None, factor=1, unit=None),
        Sensor("Upd.AutoUpdIsOn", None, factor=1, unit=None),
        Sensor("Upd.Stt", None, factor=1, unit=None),
        Sensor("WebConn.IsOn", None, factor=1, unit=None),
        Sensor("WebConn.Stt", None, factor=1, unit=None),
        Sensor("WebConn.SwRev", None, factor=1, unit=None),
        Sensor("Wl.AcqStt", None, factor=1, unit=None),
        Sensor("Wl.AntMod", None, factor=1, unit=None),
        Sensor("Wl.ConnStt", None, factor=1, unit=None),
        Sensor("Wl.SigPwr", None, factor=1, unit=None),
        Sensor("Wl.SoftAcsConnStt", None, factor=1, unit=None),
        Sensor("Operation.Bat.Health.1", Identifier.battery_status_operating_mode, factor=1, mapper=SMATagList),

        Sensor("Operation.Dmd.WCtl", Identifier.active_power_limitation, factor=1, unit="W"),
        Sensor("InOut.DigIn.CurWCtlNom", Identifier.power_limit_via_io, factor=1, unit="%"),  # codespell:ignore
        Sensor("Inverter.WMaxIn", Identifier.power_limit_in, factor=1, unit="W"),
        Sensor("Metering.DyWhOut", Identifier.daily_yield, factor=1, unit="Wh")
]
# fmt: on
name2sensor = {i.key: i for i in enneoxSensors}


def getSensorForDevice(productTagId: int) -> tuple[list[Sensor], list[str]] | None:
    """Return the profile for a device"""
    for profil in ennexosSensorProfiles:
        if productTagId in profil[0]:
            unknown: list[str] = []
            expected_sensors: list[Sensor] = []
            for sName in profil[1]:
                sensor = name2sensor.get(sName, None)
                if sensor:
                    expected_sensors.append(sensor)
                else:
                    # Sensors that have not yet been integrated into pysma
                    unknown.append(sName)
            return (expected_sensors, unknown)
    return None
